@@ -40,10 +40,7 @@
 #include "gdkprivate-directfb.h"
 #include "gdkdisplay-directfb.h"
 
-#include "gdkregion-generic.h"
-
 #include "gdkinternals.h"
-#include "gdkalias.h"
 #include "cairo.h"
 #include <assert.h>
 
@@ -57,7 +54,7 @@ D_DEBUG_DOMAIN( GDKDFB_Paintable, "GDKDFB/Paintable", "GDK DirectFB Paintable" )
 D_DEBUG_DOMAIN( GDKDFB_Window,    "GDKDFB/Window",    "GDK DirectFB Window" );
 
 
-static GdkRegion * gdk_window_impl_directfb_get_visible_region (GdkDrawable *drawable);
+static cairo_region_t * gdk_window_impl_directfb_get_visible_region (GdkDrawable *drawable);
 static void        gdk_window_impl_directfb_set_colormap       (GdkDrawable *drawable,
                                                                 GdkColormap *colormap);
 static void gdk_window_impl_directfb_init       (GdkWindowImplDirectFB      *window);
@@ -92,7 +89,7 @@ gdk_window_impl_directfb_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
         {
           sizeof (GdkWindowImplDirectFBClass),
           (GBaseInitFunc) NULL,
@@ -105,14 +102,14 @@ gdk_window_impl_directfb_get_type (void)
           (GInstanceInitFunc) gdk_window_impl_directfb_init,
         };
 
-      static const GInterfaceInfo paintable_info =
+      const GInterfaceInfo paintable_info =
         {
           (GInterfaceInitFunc) gdk_window_impl_directfb_paintable_init,
           NULL,
           NULL
         };
 
-      static const GInterfaceInfo window_impl_info =
+      const GInterfaceInfo window_impl_info =
         {
           (GInterfaceInitFunc) gdk_window_impl_iface_init,
           NULL,
@@ -185,7 +182,7 @@ gdk_window_impl_directfb_finalize (GObject *object)
 {
   GdkWindowImplDirectFB *impl = GDK_WINDOW_IMPL_DIRECTFB (object);
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p ) <- %dx%d\n", __FUNCTION__, impl, impl->drawable.width, impl->drawable.height );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p ) <- %dx%d\n", G_STRFUNC, impl, impl->drawable.width, impl->drawable.height );
 
   if (GDK_WINDOW_IS_MAPPED (impl->drawable.wrapper))
     gdk_window_hide (impl->drawable.wrapper);
@@ -209,14 +206,14 @@ gdk_window_impl_directfb_finalize (GObject *object)
     G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static GdkRegion*
+static cairo_region_t*
 gdk_window_impl_directfb_get_visible_region (GdkDrawable *drawable)
 {
   GdkDrawableImplDirectFB *priv = GDK_DRAWABLE_IMPL_DIRECTFB (drawable);
   GdkRectangle             rect = { 0, 0, 0, 0 };
   DFBRectangle             drect = { 0, 0, 0, 0 };
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, drawable );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, drawable );
 
   if (priv->surface)
   priv->surface->GetVisibleRectangle (priv->surface, &drect);
@@ -227,7 +224,7 @@ gdk_window_impl_directfb_get_visible_region (GdkDrawable *drawable)
 
   D_DEBUG_AT( GDKDFB_Window, "  -> returning %4d,%4d-%4dx%4d\n", drect.x, drect.y, drect.w, drect.h );
 
-  return gdk_region_rectangle (&rect);
+  return cairo_region_create_rectangle (&rect);
 }
 
 static void
@@ -259,7 +256,7 @@ create_directfb_window (GdkWindowImplDirectFB *impl,
   DFBResult        ret;
   IDirectFBWindow *window;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %4dx%4d, caps 0x%08x )\n", __FUNCTION__, desc->width, desc->height, desc->caps );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %4dx%4d, caps 0x%08x )\n", G_STRFUNC, desc->width, desc->height, desc->caps );
 
   ret = _gdk_display->layer->CreateWindow (_gdk_display->layer, desc, &window);
 
@@ -306,8 +303,11 @@ _gdk_windowing_window_init (void)
   _gdk_display->layer->GetConfiguration (_gdk_display->layer, &dlc);
 
   _gdk_parent_root = g_object_new (GDK_TYPE_WINDOW, NULL);
+
   private = GDK_WINDOW_OBJECT (_gdk_parent_root);
   private->impl = g_object_new (_gdk_window_impl_get_type (), NULL);
+  private->impl_window = private;
+
   impl = GDK_WINDOW_IMPL_DIRECTFB (private->impl);
 
   private->window_type = GDK_WINDOW_ROOT;
@@ -344,13 +344,15 @@ _gdk_windowing_window_init (void)
   }
   impl->drawable.surface->GetPixelFormat(impl->drawable.surface,&impl->drawable.format);
   private->depth = DFB_BITS_PER_PIXEL(impl->drawable.format);
+
+  _gdk_window_update_size (_gdk_parent_root);
+
   /*
 	Now we can set up the system colormap
   */
   gdk_drawable_set_colormap (GDK_DRAWABLE (_gdk_parent_root),gdk_colormap_get_system());
 }
 
-
 void
 _gdk_window_impl_new (GdkWindow     *window,
                       GdkWindow     *real_parent,
@@ -376,7 +378,7 @@ _gdk_window_impl_new (GdkWindow     *window,
   private->x = (attributes_mask & GDK_WA_X) ? attributes->x : 0;
   private->y = (attributes_mask & GDK_WA_Y) ? attributes->y : 0;
 
-  parent_private = private->parent;
+  parent_private = GDK_WINDOW_OBJECT (real_parent);
   parent_impl = GDK_WINDOW_IMPL_DIRECTFB (parent_private->impl);
 
   private->parent = parent_private;
@@ -540,7 +542,7 @@ gdk_directfb_window_destroy (GdkWindow *window,
 
   g_return_if_fail (GDK_IS_WINDOW (window));
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p, %srecursing, %sforeign )\n", __FUNCTION__, window,
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p, %srecursing, %sforeign )\n", G_STRFUNC, window,
               recursing ? "" : "not ", foreign_destroy ? "" : "no " );
 
   private = GDK_WINDOW_OBJECT (window);
@@ -582,7 +584,7 @@ gdk_window_destroy_notify (GdkWindow *window)
 {
   g_return_if_fail (GDK_IS_WINDOW (window));
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, window );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, window );
 
   if (!GDK_WINDOW_DESTROYED (window))
     {
@@ -631,7 +633,7 @@ gdk_directfb_change_focus (GdkWindow *new_focus_window)
   GdkWindow     *new_win;
   GdkWindow     *event_win;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, new_focus_window );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, new_focus_window );
 
   /* No focus changes while the pointer is grabbed */
   if (_gdk_directfb_pointer_grab_window)
@@ -707,7 +709,7 @@ gdk_directfb_window_raise (GdkWindow *window)
 {
   GdkWindowObject *parent;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, window );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, window );
 
   parent = GDK_WINDOW_OBJECT (window)->parent;
 
@@ -725,7 +727,7 @@ gdk_directfb_window_lower (GdkWindow *window)
 {
   GdkWindowObject *parent;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, window );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, window );
 
   parent = GDK_WINDOW_OBJECT (window)->parent;
 
@@ -756,7 +758,7 @@ send_map_events (GdkWindowObject *private)
   if (!GDK_WINDOW_IS_MAPPED (private))
     return;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, private );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, private );
 
   event_win = gdk_directfb_other_event_window ((GdkWindow *) private, GDK_MAP);
   if (event_win)
@@ -799,7 +801,7 @@ gdk_directfb_window_send_crossing_events (GdkWindow       *src,
   GdkWindow       *b;
   GdkWindow       *event_win;
 
-  D_DEBUG_AT( GDKDFB_Crossing, "%s( %p -> %p, %d )\n", __FUNCTION__, src, dest, mode );
+  D_DEBUG_AT( GDKDFB_Crossing, "%s( %p -> %p, %d )\n", G_STRFUNC, src, dest, mode );
 
   /* Do a possible cursor change before checking if we need to
      generate crossing events so cursor changes due to pointer
@@ -1052,7 +1054,7 @@ show_window_internal (GdkWindow *window,
   GdkWindowImplDirectFB *impl;
   GdkWindow             *mousewin;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p, %sraise )\n", __FUNCTION__, window, raise ? "" : "no " );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p, %sraise )\n", G_STRFUNC, window, raise ? "" : "no " );
 
   private = GDK_WINDOW_OBJECT (window);
   impl = GDK_WINDOW_IMPL_DIRECTFB (private->impl);
@@ -1096,7 +1098,7 @@ gdk_directfb_window_show (GdkWindow *window,
 {
   g_return_if_fail (GDK_IS_WINDOW (window));
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, window );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, window );
 
   show_window_internal (window, raise);
 }
@@ -1111,7 +1113,7 @@ gdk_directfb_window_hide (GdkWindow *window)
 
   g_return_if_fail (GDK_IS_WINDOW (window));
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, window );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, window );
 
   private = GDK_WINDOW_OBJECT (window);
   impl    = GDK_WINDOW_IMPL_DIRECTFB (private->impl);
@@ -1315,13 +1317,14 @@ gdk_directfb_window_move_resize (GdkWindow *window,
     }
   else if (impl->window)
     {
-      private->x = x;
-      private->y = y;
+      if (with_move) {
+        private->x = x;
+        private->y = y;
+        impl->window->MoveTo (impl->window, x, y);
+      }
       impl->drawable.width = width;
       impl->drawable.height = height;
 
-      if (with_move)
-        impl->window->MoveTo (impl->window, x, y);
       impl->window->Resize (impl->window, width, height);
     }
   else
@@ -1463,7 +1466,7 @@ gdk_window_directfb_raise (GdkWindow *window)
 {
   GdkWindowImplDirectFB *impl;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, window );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, window );
 
   g_return_if_fail (GDK_IS_WINDOW (window));
 
@@ -1494,7 +1497,7 @@ gdk_window_directfb_lower (GdkWindow *window)
 {
   GdkWindowImplDirectFB *impl;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, window );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, window );
 
   g_return_if_fail (GDK_IS_WINDOW (window));
 
@@ -1520,26 +1523,6 @@ gdk_window_directfb_lower (GdkWindow *window)
     }
 }
 
-void
-gdk_window_set_hints (GdkWindow *window,
-                      gint       x,
-                      gint       y,
-                      gint       min_width,
-                      gint       min_height,
-                      gint       max_width,
-                      gint       max_height,
-                      gint       flags)
-{
-  g_return_if_fail (GDK_IS_WINDOW (window));
-
-  if (GDK_WINDOW_DESTROYED (window))
-    return;
-
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p, %3d,%3d, min %4dx%4d, max %4dx%4d, flags 0x%08x )\n", __FUNCTION__,
-              window, x,y, min_width, min_height, max_width, max_height, flags );
-  /* N/A */
-}
-
 void
 gdk_window_set_geometry_hints (GdkWindow         *window,
                                const GdkGeometry *geometry,
@@ -1562,9 +1545,9 @@ gdk_window_set_title (GdkWindow   *window,
   if (GDK_WINDOW_DESTROYED (window))
     return;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p, '%s' )\n", __FUNCTION__, window, title );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p, '%s' )\n", G_STRFUNC, window, title );
   /* N/A */
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, window );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, window );
 }
 
 void
@@ -1632,7 +1615,7 @@ gdk_directfb_window_set_background (GdkWindow *window,
 
   g_return_if_fail (color != NULL);
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p, %d,%d,%d )\n", __FUNCTION__, window, color->red, color->green, color->blue );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p, %d,%d,%d )\n", G_STRFUNC, window, color->red, color->green, color->blue );
 
   private = GDK_WINDOW_OBJECT (window);
   private->bg_color = *color;
@@ -1653,7 +1636,7 @@ gdk_directfb_window_set_back_pixmap (GdkWindow *window,
 
   g_return_if_fail (GDK_IS_WINDOW (window));
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p, %p )\n", __FUNCTION__,
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p, %p )\n", G_STRFUNC,
               window, pixmap);
 
   private = GDK_WINDOW_OBJECT (window);
@@ -1781,7 +1764,7 @@ _gdk_directfb_calc_abs (GdkWindow *window)
       impl->abs_y += parent_impl->abs_y;
     }
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p ) -> %4d,%4d\n", __FUNCTION__, window, impl->abs_x, impl->abs_y );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p ) -> %4d,%4d\n", G_STRFUNC, window, impl->abs_x, impl->abs_y );
 
   for (list = private->children; list; list = list->next)
     {
@@ -1870,20 +1853,14 @@ GdkWindow *
 _gdk_windowing_window_at_pointer (GdkDisplay *display,
                                   gint       *win_x,
 				  gint       *win_y,
-                                  GdkModifierType *mask)
+                                  GdkModifierType *mask,
+                                  gboolean get_toplevel)
 {
   GdkWindow *retval;
   gint       wx, wy;
 
-  if (!win_x || !win_y)
   gdk_directfb_mouse_get_info (&wx, &wy, NULL);
 
-  if (win_x)
-    wx = *win_x;
-
-  if (win_y)
-    wy = *win_y;
-
   retval = gdk_directfb_child_at (_gdk_parent_root, &wx, &wy);
 
   if (win_x)
@@ -1892,6 +1869,26 @@ _gdk_windowing_window_at_pointer (GdkDisplay *display,
   if (win_y)
     *win_y = wy;
 
+  if (get_toplevel)
+    {
+      GdkWindowObject *w = (GdkWindowObject *)retval;
+      /* Requested toplevel, find it. */
+      /* TODO: This can be implemented more efficient by never
+	 recursing into children in the first place */
+      if (w)
+	{
+	  /* Convert to toplevel */
+	  while (w->parent != NULL &&
+		 w->parent->window_type != GDK_WINDOW_ROOT)
+	    {
+	      *win_x += w->x;
+	      *win_y += w->y;
+	      w = w->parent;
+	    }
+	  retval = (GdkWindow *)w;
+	}
+    }
+
   return retval;
 }
 
@@ -1910,7 +1907,8 @@ _gdk_windowing_get_pointer (GdkDisplay       *display,
   gdk_directfb_window_get_pointer (_gdk_windowing_window_at_pointer (display,
                                                                      NULL,
                                                                      NULL,
-                                                                     NULL),
+                                                                     NULL,
+                                                                     FALSE),
                                    x, y, mask);
 }
 
@@ -1941,7 +1939,7 @@ gdk_directfb_window_set_events (GdkWindow    *window,
 
 static void
 gdk_directfb_window_shape_combine_region (GdkWindow       *window,
-                                          const GdkRegion *shape_region,
+                                          const cairo_region_t *shape_region,
                                           gint             offset_x,
                                           gint             offset_y)
 {
@@ -1949,7 +1947,7 @@ gdk_directfb_window_shape_combine_region (GdkWindow       *window,
 
 void
 gdk_directfb_window_input_shape_combine_region (GdkWindow       *window,
-                                                const GdkRegion *shape_region,
+                                                const cairo_region_t *shape_region,
                                                 gint             offset_x,
                                                 gint             offset_y)
 {
@@ -1958,7 +1956,7 @@ gdk_directfb_window_input_shape_combine_region (GdkWindow       *window,
 static void
 gdk_directfb_window_queue_translation (GdkWindow *window,
 				       GdkGC     *gc,
-                                       GdkRegion *region,
+                                       cairo_region_t *region,
                                        gint       dx,
                                        gint       dy)
 {
@@ -2273,7 +2271,7 @@ gdk_window_set_functions (GdkWindow     *window,
     return;
 
   /* N/A */
-  g_message("unimplemented %s", __FUNCTION__);
+  g_message("unimplemented %s", G_STRFUNC);
 }
 
 static gboolean
@@ -2286,7 +2284,7 @@ gdk_directfb_window_set_static_gravities (GdkWindow *window,
     return FALSE;
 
   /* N/A */
-  g_message("unimplemented %s", __FUNCTION__);
+  g_message("unimplemented %s", G_STRFUNC);
 
   return FALSE;
 }
@@ -2304,7 +2302,7 @@ gdk_window_begin_resize_drag (GdkWindow     *window,
   if (GDK_WINDOW_DESTROYED (window))
     return;
 
-  g_message("unimplemented %s", __FUNCTION__);
+  g_message("unimplemented %s", G_STRFUNC);
 }
 
 void
@@ -2319,7 +2317,7 @@ gdk_window_begin_move_drag (GdkWindow *window,
   if (GDK_WINDOW_DESTROYED (window))
     return;
 
-  g_message("unimplemented %s", __FUNCTION__);
+  g_message("unimplemented %s", G_STRFUNC);
 }
 
 /**
@@ -2621,7 +2619,7 @@ gdk_window_set_urgency_hint (GdkWindow *window,
 static void
 gdk_window_impl_directfb_begin_paint_region (GdkPaintable    *paintable,
                                              GdkWindow       *window,
-                                             const GdkRegion *region)
+                                             const cairo_region_t *region)
 {
   GdkDrawableImplDirectFB *impl;
   GdkWindowImplDirectFB   *wimpl;
@@ -2634,7 +2632,7 @@ gdk_window_impl_directfb_begin_paint_region (GdkPaintable    *paintable,
   if (!region)
     return;
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p ) <- %4d,%4d-%4d,%4d (%ld boxes)\n", __FUNCTION__,
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p ) <- %4d,%4d-%4d,%4d (%ld boxes)\n", G_STRFUNC,
               paintable, GDKDFB_RECTANGLE_VALS_FROM_BOX(&region->extents), region->numRects );
 
   /* When it's buffered... */
@@ -2647,7 +2645,7 @@ gdk_window_impl_directfb_begin_paint_region (GdkPaintable    *paintable,
                   DFB_RECTANGLE_VALS_FROM_REGION( &impl->paint_region.extents ), impl->paint_region.numRects );
 
       /* Add the new region to the paint region... */
-      gdk_region_union (&impl->paint_region, region);
+      cairo_region_union (&impl->paint_region, region);
     }
   else
     {
@@ -2667,7 +2665,7 @@ gdk_window_impl_directfb_begin_paint_region (GdkPaintable    *paintable,
               DFB_RECTANGLE_VALS_FROM_REGION( &impl->paint_region.extents ), impl->paint_region.numRects );
 
   /* ...but clip the initial/compound result against the clip region. */
-  gdk_region_intersect (&impl->paint_region, &impl->clip_region);
+  cairo_region_intersect (&impl->paint_region, &impl->clip_region);
 
   D_DEBUG_AT( GDKDFB_Window, "  -> clipped  %4d,%4d-%4dx%4d (%ld boxes)\n",
               DFB_RECTANGLE_VALS_FROM_REGION( &impl->paint_region.extents ), impl->paint_region.numRects );
@@ -2678,7 +2676,7 @@ gdk_window_impl_directfb_begin_paint_region (GdkPaintable    *paintable,
 
   for (i = 0; i < region->numRects; i++)
     {
-      GdkRegionBox *box = &region->rects[i];
+      cairo_region_tBox *box = &region->rects[i];
 
       D_DEBUG_AT( GDKDFB_Window, "  -> [%2d] %4d,%4d-%4dx%4d\n", i, GDKDFB_RECTANGLE_VALS_FROM_BOX( box ) );
 
@@ -2697,7 +2695,7 @@ gdk_window_impl_directfb_end_paint (GdkPaintable *paintable)
 
   impl = GDK_DRAWABLE_IMPL_DIRECTFB (paintable);
 
-  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", __FUNCTION__, paintable );
+  D_DEBUG_AT( GDKDFB_Window, "%s( %p )\n", G_STRFUNC, paintable );
 
   g_return_if_fail (impl->paint_depth > 0);
 
@@ -2765,13 +2763,13 @@ gdk_window_impl_directfb_end_paint (GdkPaintable *paintable)
     D_DEBUG_AT( GDKDFB_Window, "  -> depth is still %d\n", impl->paint_depth );
 }
 
-GdkRegion *
+cairo_region_t *
 _gdk_windowing_get_shape_for_mask (GdkBitmap *mask)
 {
   return NULL;
 }
 
-GdkRegion *
+cairo_region_t *
 _gdk_windowing_window_get_shape (GdkWindow *window)
 {
   return NULL;
@@ -2783,7 +2781,7 @@ _gdk_windowing_window_get_next_serial (GdkDisplay *display)
   return 0;
 }
 
-GdkRegion *
+cairo_region_t *
 _gdk_windowing_window_get_input_shape (GdkWindow *window)
 {
   return NULL;
@@ -2801,7 +2799,7 @@ _gdk_windowing_after_process_all_updates (void)
 
 void
 _gdk_windowing_window_process_updates_recurse (GdkWindow *window,
-                                               GdkRegion *region)
+                                               cairo_region_t *region)
 {
   _gdk_window_process_updates_recurse (window, region);
 }
@@ -2860,7 +2858,7 @@ gdk_directfb_window_get_root_coords (GdkWindow *window,
 
 static gboolean
 gdk_directfb_window_queue_antiexpose (GdkWindow *window,
-                                      GdkRegion *area)
+                                      cairo_region_t *area)
 {
   return FALSE;
 }
@@ -2891,7 +2889,3 @@ gdk_window_impl_iface_init (GdkWindowImplIface *iface)
   iface->queue_translation = gdk_directfb_window_queue_translation;
   iface->destroy = gdk_directfb_window_destroy;
 }
-
-#define __GDK_WINDOW_X11_C__
-#include "gdkaliasdef.c"
-
