@@ -36,8 +36,6 @@ gdk_quartz_gc_get_values (GdkGC       *gc,
   values->foreground.pixel = _gdk_gc_get_fg_pixel (gc);
   values->background.pixel = _gdk_gc_get_bg_pixel (gc);
 
-  values->font = private->font;
-
   values->function = private->function;
 
   values->fill = _gdk_gc_get_fill (gc);
@@ -84,7 +82,7 @@ create_clip_mask (GdkPixmap *source_pixmap)
    * future, we would look into doing this by hand on the actual raw
    * data.
    */
-  source = _gdk_pixmap_get_cgimage (source_pixmap);
+  source = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (source_pixmap)->impl)->image;
 
   width = CGImageGetWidth (source);
   height = CGImageGetHeight (source);
@@ -130,11 +128,6 @@ gdk_quartz_gc_set_values (GdkGC           *gc,
 {
   GdkGCQuartz *private = GDK_GC_QUARTZ (gc);
 
-  if (mask & GDK_GC_FONT)
-    {
-      /* FIXME: implement font */
-    }
-
   if (mask & GDK_GC_FUNCTION)
     private->function = values->function;
 
@@ -271,7 +264,7 @@ _gdk_quartz_gc_new (GdkDrawable      *drawable,
 
 void
 _gdk_windowing_gc_set_clip_region (GdkGC           *gc,
-				   const GdkRegion *region,
+				   const cairo_region_t *region,
 				   gboolean         reset_origin)
 {
   GdkGCQuartz *private = GDK_GC_QUARTZ (gc);
@@ -302,12 +295,6 @@ _gdk_windowing_gc_copy (GdkGC *dst_gc,
   GdkGCQuartz *dst_quartz_gc = GDK_GC_QUARTZ (dst_gc);
   GdkGCQuartz *src_quartz_gc = GDK_GC_QUARTZ (src_gc);
 
-  if (dst_quartz_gc->font)
-    gdk_font_unref (dst_quartz_gc->font);
-  dst_quartz_gc->font = src_quartz_gc->font;
-  if (dst_quartz_gc->font)
-    gdk_font_ref (dst_quartz_gc->font);
-
   dst_quartz_gc->function = src_quartz_gc->function;
   dst_quartz_gc->subwindow_mode = src_quartz_gc->subwindow_mode;
   dst_quartz_gc->graphics_exposures = src_quartz_gc->graphics_exposures;
@@ -322,7 +309,8 @@ _gdk_windowing_gc_copy (GdkGC *dst_gc,
     }
   
   if (src_quartz_gc->clip_mask)
-    dst_quartz_gc->clip_mask = _gdk_pixmap_get_cgimage (GDK_PIXMAP (src_quartz_gc->clip_mask));
+    dst_quartz_gc->clip_mask =
+      CGImageCreateCopy (GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (src_quartz_gc->clip_mask)->impl)->image);
 
   dst_quartz_gc->line_width = src_quartz_gc->line_width;
   dst_quartz_gc->line_style = src_quartz_gc->line_style;
@@ -363,7 +351,7 @@ gdk_quartz_draw_tiled_pattern (void         *info,
   CGImageRef   pattern_image;
   size_t       width, height;
 
-  pattern_image = _gdk_pixmap_get_cgimage (GDK_PIXMAP_OBJECT (_gdk_gc_get_tile (gc))->impl);
+  pattern_image = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (_gdk_gc_get_tile (gc))->impl)->image;
 
   width = CGImageGetWidth (pattern_image);
   height = CGImageGetHeight (pattern_image);
@@ -371,7 +359,6 @@ gdk_quartz_draw_tiled_pattern (void         *info,
   CGContextDrawImage (context, 
 		      CGRectMake (0, 0, width, height),
 		      pattern_image);
-  CGImageRelease (pattern_image);
 }
 
 static void
@@ -384,7 +371,7 @@ gdk_quartz_draw_stippled_pattern (void         *info,
   CGRect      rect;
   CGColorRef  color;
 
-  pattern_image = _gdk_pixmap_get_cgimage (GDK_PIXMAP_OBJECT (_gdk_gc_get_stipple (gc))->impl);
+  pattern_image = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (_gdk_gc_get_stipple (gc))->impl)->image;
   rect = CGRectMake (0, 0,
 		     CGImageGetWidth (pattern_image),
 		     CGImageGetHeight (pattern_image));
@@ -396,8 +383,6 @@ gdk_quartz_draw_stippled_pattern (void         *info,
   CGColorRelease (color);
 
   CGContextFillRect (context, rect);
-
-  CGImageRelease (pattern_image);
 }
 
 static void
@@ -410,7 +395,7 @@ gdk_quartz_draw_opaque_stippled_pattern (void         *info,
   CGRect      rect;
   CGColorRef  color;
 
-  pattern_image = _gdk_pixmap_get_cgimage (GDK_PIXMAP_OBJECT (_gdk_gc_get_stipple (gc))->impl);
+  pattern_image = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (_gdk_gc_get_stipple (gc))->impl)->image;
   rect = CGRectMake (0, 0,
 		     CGImageGetWidth (pattern_image),
 		     CGImageGetHeight (pattern_image));
@@ -429,8 +414,6 @@ gdk_quartz_draw_opaque_stippled_pattern (void         *info,
   CGColorRelease (color);
 
   CGContextFillRect (context, rect);
-
-  CGImageRelease (pattern_image);
 }
 
 void
@@ -454,11 +437,11 @@ _gdk_quartz_gc_update_cg_context (GdkGC                      *gc,
     {
       CGRect rect;
       CGRect *cg_rects;
-      GdkRectangle *rects;
+      cairo_region_t *region;
       gint n_rects, i;
 
-      gdk_region_get_rectangles (_gdk_gc_get_clip_region (gc),
-				 &rects, &n_rects);
+      region = _gdk_gc_get_clip_region (gc);
+      n_rects = cairo_region_num_rectangles (region);
 
       if (n_rects == 1)
 	cg_rects = &rect;
@@ -467,15 +450,16 @@ _gdk_quartz_gc_update_cg_context (GdkGC                      *gc,
 
       for (i = 0; i < n_rects; i++)
 	{
-	  cg_rects[i].origin.x = rects[i].x + gc->clip_x_origin;
-	  cg_rects[i].origin.y = rects[i].y + gc->clip_y_origin;
-	  cg_rects[i].size.width = rects[i].width;
-	  cg_rects[i].size.height = rects[i].height;
+          cairo_rectangle_int_t cairo_rect;
+          cairo_region_get_rectangle (region, i, &cairo_rect);
+	  cg_rects[i].origin.x = cairo_rect.x + gc->clip_x_origin;
+	  cg_rects[i].origin.y = cairo_rect.y + gc->clip_y_origin;
+	  cg_rects[i].size.width = cairo_rect.width;
+	  cg_rects[i].size.height = cairo_rect.height;
 	}
 
       CGContextClipToRects (context, cg_rects, n_rects);
 
-      g_free (rects);
       if (cg_rects != &rect)
 	g_free (cg_rects);
     }
@@ -615,12 +599,12 @@ _gdk_quartz_gc_update_cg_context (GdkGC                      *gc,
 	{
 	  if (!private->ts_pattern)
 	    {
+	      CGImageRef pattern_image = NULL;
 	      gfloat     width, height;
 	      gboolean   is_colored = FALSE;
 	      CGPatternCallbacks callbacks =  { 0, NULL, NULL };
               struct PatternCallbackInfo *info;
 	      CGPoint    phase;
-              GdkPixmapImplQuartz *pix_impl = NULL;
 
               info = g_new (struct PatternCallbackInfo, 1);
               /* Won't ref to avoid circular dependencies */
@@ -632,23 +616,17 @@ _gdk_quartz_gc_update_cg_context (GdkGC                      *gc,
 	      switch (fill)
 		{
 		case GDK_TILED:
-		  pix_impl = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (_gdk_gc_get_tile (gc))->impl);
-		  width = pix_impl->width;
-		  height = pix_impl->height;
+		  pattern_image = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (_gdk_gc_get_tile (gc))->impl)->image;
 		  is_colored = TRUE;
 		  callbacks.drawPattern = gdk_quartz_draw_tiled_pattern;
 		  break;
 		case GDK_STIPPLED:
-		  pix_impl = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (_gdk_gc_get_stipple (gc))->impl);
-		  width = pix_impl->width;
-		  height = pix_impl->height;
+		  pattern_image = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (_gdk_gc_get_stipple (gc))->impl)->image;
 		  is_colored = FALSE;
 		  callbacks.drawPattern = gdk_quartz_draw_stippled_pattern;
 		  break;
 		case GDK_OPAQUE_STIPPLED:
-		  pix_impl = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (_gdk_gc_get_stipple (gc))->impl);
-		  width = pix_impl->width;
-		  height = pix_impl->height;
+		  pattern_image = GDK_PIXMAP_IMPL_QUARTZ (GDK_PIXMAP_OBJECT (_gdk_gc_get_stipple (gc))->impl)->image;
 		  is_colored = TRUE;
 		  callbacks.drawPattern = gdk_quartz_draw_opaque_stippled_pattern;
 		  break;
@@ -656,6 +634,9 @@ _gdk_quartz_gc_update_cg_context (GdkGC                      *gc,
 		  break;
 		}
 
+	      width  = CGImageGetWidth (pattern_image);
+	      height = CGImageGetHeight (pattern_image);
+
 	      phase = CGPointApplyAffineTransform (CGPointMake (gc->ts_x_origin, gc->ts_y_origin), CGContextGetCTM (context));
 	      CGContextSetPatternPhase (context, CGSizeMake (phase.x, phase.y));
 
