@@ -24,15 +24,37 @@
 
 void
 _gdk_quartz_window_queue_translation (GdkWindow *window,
-                                      GdkRegion *area,
+				      GdkGC     *gc,
+                                      cairo_region_t *area,
                                       gint       dx,
                                       gint       dy)
 {
+  GdkWindowObject *private = (GdkWindowObject *)window;
+  GdkWindowImplQuartz *impl = (GdkWindowImplQuartz *)private->impl;
+
+  int i, n_rects;
+  cairo_region_t *intersection;
+  GdkRectangle rect;
+
+  /* We will intersect the known region that needs display with the given
+   * area.  This intersection will be translated by dx, dy.  For the end
+   * result, we will also set that it needs display.
+   */
+
+  if (!impl->needs_display_region)
+    return;
+
+  intersection = cairo_region_copy (impl->needs_display_region);
+  cairo_region_intersect (intersection, area);
+  cairo_region_translate (intersection, dx, dy);
+
+  _gdk_quartz_window_set_needs_display_in_region (window, intersection);
+  cairo_region_destroy (intersection);
 }
 
 gboolean
 _gdk_quartz_window_queue_antiexpose (GdkWindow *window,
-                                     GdkRegion *area)
+                                     cairo_region_t *area)
 {
   return FALSE;
 }
