@@ -23,6 +23,7 @@
 #include <Carbon/Carbon.h>
 
 #include "gdk.h"
+#include "gdkdeviceprivate.h"
 #include "gdkwindowimpl.h"
 #include "gdkprivate-quartz.h"
 #include "gdkscreen-quartz.h"
@@ -111,28 +112,28 @@ gdk_window_impl_quartz_get_context (GdkDrawable *drawable,
     {
       CGRect rect;
       CGRect *cg_rects;
-      GdkRectangle *rects;
       gint n_rects, i;
 
-      gdk_region_get_rectangles (window_impl->paint_clip_region,
-                                 &rects, &n_rects);
+      n_rects = cairo_region_num_rectangles (window_impl->paint_clip_region);
 
       if (n_rects == 1)
-        cg_rects = &rect;
+	cg_rects = &rect;
       else
-        cg_rects = g_new (CGRect, n_rects);
+	cg_rects = g_new (CGRect, n_rects);
 
       for (i = 0; i < n_rects; i++)
-        {
-          cg_rects[i].origin.x = rects[i].x;
-          cg_rects[i].origin.y = rects[i].y;
-          cg_rects[i].size.width = rects[i].width;
-          cg_rects[i].size.height = rects[i].height;
-        }
+	{
+          cairo_rectangle_int_t cairo_rect;
+          cairo_region_get_rectangle (window_impl->paint_clip_region,
+                                      i, &cairo_rect);
+	  cg_rects[i].origin.x = cairo_rect.x;
+	  cg_rects[i].origin.y = cairo_rect.y;
+	  cg_rects[i].size.width = cairo_rect.width;
+	  cg_rects[i].size.height = cairo_rect.height;
+	}
 
       CGContextClipToRects (cg_context, cg_rects, n_rects);
 
-      g_free (rects);
       if (cg_rects != &rect)
         g_free (cg_rects);
     }
@@ -143,41 +144,47 @@ gdk_window_impl_quartz_get_context (GdkDrawable *drawable,
 static void
 check_grab_unmap (GdkWindow *window)
 {
+  GList *list, *l;
   GdkDisplay *display = gdk_drawable_get_display (window);
+  GdkDeviceManager *device_manager;
 
-  _gdk_display_end_pointer_grab (display, 0, window, TRUE);
-
-  if (display->keyboard_grab.window)
+  device_manager = gdk_display_get_device_manager (display);
+  list = gdk_device_manager_list_devices (device_manager,
+                                          GDK_DEVICE_TYPE_FLOATING);
+  for (l = list; l; l = l->next)
     {
-      GdkWindowObject *private = GDK_WINDOW_OBJECT (window);
-      GdkWindowObject *tmp = GDK_WINDOW_OBJECT (display->keyboard_grab.window);
-
-      while (tmp && tmp != private)
-	tmp = tmp->parent;
-
-      if (tmp)
-	_gdk_display_unset_has_keyboard_grab (display, TRUE);
+      _gdk_display_end_device_grab (display, l->data, 0, window, TRUE);
     }
+
+  g_list_free (list);
 }
 
 static void
 check_grab_destroy (GdkWindow *window)
 {
+  GList *list, *l;
   GdkDisplay *display = gdk_drawable_get_display (window);
-  GdkPointerGrabInfo *grab;
+  GdkDeviceManager *device_manager;
 
   /* Make sure there is no lasting grab in this native window */
-  grab = _gdk_display_get_last_pointer_grab (display);
-  if (grab && grab->native_window == window)
+  device_manager = gdk_display_get_device_manager (display);
+  list = gdk_device_manager_list_devices (device_manager,
+                                          GDK_DEVICE_TYPE_MASTER);
+
+  for (l = list; l; l = l->next)
     {
-      /* Serials are always 0 in quartz, but for clarity: */
-      grab->serial_end = grab->serial_start;
-      grab->implicit_ungrab = TRUE;
+      GdkDeviceGrabInfo *grab;
+
+      grab = _gdk_display_get_last_device_grab (display, l->data);
+      if (grab && grab->native_window == window)
+        {
+          /* Serials are always 0 in quartz, but for clarity: */
+          grab->serial_end = grab->serial_start;
+          grab->implicit_ungrab = TRUE;
+        }
     }
 
-  if (window == display->keyboard_grab.native_window &&
-      display->keyboard_grab.window != NULL)
-    _gdk_display_unset_has_keyboard_grab (display, TRUE);
+  g_list_free (list);
 }
 
 static void
@@ -188,7 +195,7 @@ gdk_window_impl_quartz_finalize (GObject *object)
   check_grab_destroy (GDK_DRAWABLE_IMPL_QUARTZ (object)->wrapper);
 
   if (impl->paint_clip_region)
-    gdk_region_destroy (impl->paint_clip_region);
+    cairo_region_destroy (impl->paint_clip_region);
 
   if (impl->transient_for)
     g_object_unref (impl->transient_for);
@@ -218,23 +225,22 @@ gdk_window_impl_quartz_init (GdkWindowImplQuartz *impl)
 static void
 gdk_window_impl_quartz_begin_paint_region (GdkPaintable    *paintable,
                                            GdkWindow       *window,
-					   const GdkRegion *region)
+					   const cairo_region_t *region)
 {
   GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (paintable);
   GdkWindowObject *private = (GdkWindowObject*)window;
   int n_rects;
-  GdkRectangle *rects = NULL;
   GdkPixmap *bg_pixmap;
-  GdkRegion *clipped_and_offset_region;
+  cairo_region_t *clipped_and_offset_region;
   gboolean free_clipped_and_offset_region = TRUE;
 
   bg_pixmap = private->bg_pixmap;
 
-  clipped_and_offset_region = gdk_region_copy (region);
+  clipped_and_offset_region = cairo_region_copy (region);
 
-  gdk_region_intersect (clipped_and_offset_region,
+  cairo_region_intersect (clipped_and_offset_region,
                         private->clip_region_with_children);
-  gdk_region_offset (clipped_and_offset_region,
+  cairo_region_translate (clipped_and_offset_region,
                      private->abs_x, private->abs_y);
 
   if (impl->begin_paint_count == 0)
@@ -243,14 +249,14 @@ gdk_window_impl_quartz_begin_paint_region (GdkPaintable    *paintable,
       free_clipped_and_offset_region = FALSE;
     }
   else
-    gdk_region_union (impl->paint_clip_region, clipped_and_offset_region);
+    cairo_region_union (impl->paint_clip_region, clipped_and_offset_region);
 
   impl->begin_paint_count++;
 
   if (bg_pixmap == GDK_NO_BG)
     goto done;
 
-  gdk_region_get_rectangles (clipped_and_offset_region, &rects, &n_rects);
+  n_rects = cairo_region_num_rectangles (clipped_and_offset_region);
 
   if (n_rects == 0)
     goto done;
@@ -269,9 +275,11 @@ gdk_window_impl_quartz_begin_paint_region (GdkPaintable    *paintable,
  
       for (i = 0; i < n_rects; i++)
         {
+          cairo_rectangle_int_t rect;
+          cairo_region_get_rectangle (clipped_and_offset_region, i, &rect);
           CGContextFillRect (cg_context,
-                             CGRectMake (rects[i].x, rects[i].y,
-                                         rects[i].width, rects[i].height));
+                             CGRectMake (rect.x, rect.y,
+                                         rect.width, rect.height));
         }
 
       gdk_quartz_drawable_release_context (GDK_DRAWABLE (impl), cg_context);
@@ -281,6 +289,7 @@ gdk_window_impl_quartz_begin_paint_region (GdkPaintable    *paintable,
       int x, y;
       int x_offset, y_offset;
       int width, height;
+      cairo_rectangle_int_t rect;
       GdkGC *gc;
 
       x_offset = y_offset = 0;
@@ -313,14 +322,15 @@ gdk_window_impl_quartz_begin_paint_region (GdkPaintable    *paintable,
       gdk_drawable_get_size (GDK_DRAWABLE (bg_pixmap), &width, &height);
 
       x = -x_offset;
-      while (x < (rects[0].x + rects[0].width))
+      cairo_region_get_rectangle (clipped_and_offset_region, 0, &rect);
+      while (x < (rect.x + rect.width))
         {
-          if (x + width >= rects[0].x)
+          if (x + width >= rect.x)
 	    {
               y = -y_offset;
-              while (y < (rects[0].y + rects[0].height))
+              while (y < (rect.y + rect.height))
                 {
-                  if (y + height >= rects[0].y)
+                  if (y + height >= rect.y)
                     gdk_draw_drawable (GDK_DRAWABLE (impl), gc, bg_pixmap, 0, 0, x, y, width, height);
 		  
                   y += height;
@@ -334,8 +344,7 @@ gdk_window_impl_quartz_begin_paint_region (GdkPaintable    *paintable,
 
  done:
   if (free_clipped_and_offset_region)
-    gdk_region_destroy (clipped_and_offset_region);
-  g_free (rects);
+    cairo_region_destroy (clipped_and_offset_region);
 }
 
 static void
@@ -347,38 +356,41 @@ gdk_window_impl_quartz_end_paint (GdkPaintable *paintable)
 
   if (impl->begin_paint_count == 0)
     {
-      gdk_region_destroy (impl->paint_clip_region);
+      cairo_region_destroy (impl->paint_clip_region);
       impl->paint_clip_region = NULL;
     }
 }
 
 void
-_gdk_quartz_window_set_needs_display_in_rect (GdkWindow    *window,
-                                              GdkRectangle *rect)
+_gdk_quartz_window_set_needs_display_in_region (GdkWindow    *window,
+                                                cairo_region_t    *region)
 {
   GdkWindowObject *private;
   GdkWindowImplQuartz *impl;
+  int i, n_rects;
 
   private = GDK_WINDOW_OBJECT (window);
   impl = GDK_WINDOW_IMPL_QUARTZ (private->impl);
 
   if (!impl->needs_display_region)
-    impl->needs_display_region = gdk_region_new ();
+    impl->needs_display_region = cairo_region_create ();
 
-  gdk_region_union_with_rect (impl->needs_display_region, rect);
-
-  [impl->view setNeedsDisplayInRect:NSMakeRect (rect->x, rect->y,
-                                                rect->width, rect->height)];
+  cairo_region_union (impl->needs_display_region, region);
 
+  n_rects = cairo_region_num_rectangles (region);
+  for (i = 0; i < n_rects; i++)
+    {
+      cairo_rectangle_int_t rect;
+      cairo_region_get_rectangle (region, i, &rect);
+      [impl->view setNeedsDisplayInRect:NSMakeRect (rect.x, rect.y,
+                                                    rect.width, rect.height)];
+    }
 }
 
 void
 _gdk_windowing_window_process_updates_recurse (GdkWindow *window,
-                                               GdkRegion *region)
+                                               cairo_region_t *region)
 {
-  int i, n_rects;
-  GdkRectangle *rects;
-
   /* Make sure to only flush each toplevel at most once if we're called
    * from process_all_updates.
    */
@@ -386,8 +398,8 @@ _gdk_windowing_window_process_updates_recurse (GdkWindow *window,
     {
       GdkWindow *toplevel;
 
-      toplevel = gdk_window_get_effective_toplevel (window);
-      if (toplevel && WINDOW_IS_TOPLEVEL (toplevel))
+      toplevel = gdk_window_get_toplevel (window);
+      if (toplevel)
         {
           GdkWindowObject *toplevel_private;
           GdkWindowImplQuartz *toplevel_impl;
@@ -409,17 +421,7 @@ _gdk_windowing_window_process_updates_recurse (GdkWindow *window,
         }
     }
 
-  if (WINDOW_IS_TOPLEVEL (window))
-    {
-      gdk_region_get_rectangles (region, &rects, &n_rects);
-
-      for (i = 0; i < n_rects; i++)
-        _gdk_quartz_window_set_needs_display_in_rect (window, &rects[i]);
-
-      g_free (rects);
-    }
-  else
-    _gdk_window_process_updates_recurse (window, region);
+  _gdk_quartz_window_set_needs_display_in_region (window, region);
 
   /* NOTE: I'm not sure if we should displayIfNeeded here. It slows down a
    * lot (since it triggers the beam syncing) and things seem to work
@@ -588,7 +590,7 @@ _gdk_quartz_window_debug_highlight (GdkWindow *window, gint number)
       return;
     }
 
-  toplevel = gdk_window_get_effective_toplevel (window);
+  toplevel = gdk_window_get_toplevel (window);
   get_ancestor_coordinates_from_child (window, 0, 0, toplevel, &x, &y);
 
   gdk_window_get_origin (toplevel, &tx, &ty);
@@ -706,7 +708,8 @@ find_child_window_helper (GdkWindow *window,
 			  gint       x,
 			  gint       y,
 			  gint       x_offset,
-			  gint       y_offset)
+			  gint       y_offset,
+                          gboolean   get_toplevel)
 {
   GdkWindowImplQuartz *impl;
   GList *l;
@@ -759,13 +762,15 @@ find_child_window_helper (GdkWindow *window,
             }
         }
 
-      if (x >= temp_x && y >= temp_y &&
+      if ((!get_toplevel || (get_toplevel && window == _gdk_root)) &&
+          x >= temp_x && y >= temp_y &&
 	  x < temp_x + child_private->width && y < temp_y + child_private->height)
 	{
 	  /* Look for child windows. */
 	  return find_child_window_helper (l->data,
 					   x, y,
-					   temp_x, temp_y);
+					   temp_x, temp_y,
+                                           get_toplevel);
 	}
     }
   
@@ -779,12 +784,13 @@ find_child_window_helper (GdkWindow *window,
 GdkWindow *
 _gdk_quartz_window_find_child (GdkWindow *window,
 			       gint       x,
-			       gint       y)
+			       gint       y,
+                               gboolean   get_toplevel)
 {
   GdkWindowObject *private = GDK_WINDOW_OBJECT (window);
 
   if (x >= 0 && y >= 0 && x < private->width && y < private->height)
-    return find_child_window_helper (window, x, y, 0, 0);
+    return find_child_window_helper (window, x, y, 0, 0, get_toplevel);
 
   return NULL;
 }
@@ -812,7 +818,7 @@ _gdk_quartz_window_did_resign_main (GdkWindow *window)
     {
       GList *toplevels;
 
-      toplevels = gdk_window_get_toplevels ();
+      toplevels = gdk_screen_get_toplevel_windows (gdk_screen_get_default ());
       if (toplevels)
         new_window = toplevels->data;
       g_list_free (toplevels);
@@ -821,7 +827,7 @@ _gdk_quartz_window_did_resign_main (GdkWindow *window)
   if (new_window &&
       new_window != window &&
       GDK_WINDOW_IS_MAPPED (new_window) &&
-      WINDOW_IS_TOPLEVEL (new_window))
+      GDK_WINDOW_OBJECT (new_window)->window_type != GDK_WINDOW_TEMP)
     {
       GdkWindowObject *private = (GdkWindowObject *) new_window;
       GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (private->impl);
@@ -1185,7 +1191,7 @@ gdk_window_quartz_show (GdkWindow *window, gboolean already_mapped)
   else
     focus_on_map = TRUE;
 
-  if (impl->toplevel && WINDOW_IS_TOPLEVEL (window))
+  if (impl->toplevel)
     {
       gboolean make_key;
 
@@ -1280,7 +1286,7 @@ gdk_window_quartz_hide (GdkWindow *window)
 
   impl = GDK_WINDOW_IMPL_QUARTZ (private->impl);
 
-  if (window && WINDOW_IS_TOPLEVEL (window))
+  if (impl->toplevel) 
     {
      /* Update main window. */
       main_window_stack = g_slist_remove (main_window_stack, window);
@@ -1316,8 +1322,8 @@ move_resize_window_internal (GdkWindow *window,
   GdkRectangle old_visible;
   GdkRectangle new_visible;
   GdkRectangle scroll_rect;
-  GdkRegion *old_region;
-  GdkRegion *expose_region;
+  cairo_region_t *old_region;
+  cairo_region_t *expose_region;
   NSSize delta;
 
   if (GDK_WINDOW_DESTROYED (window))
@@ -1341,9 +1347,9 @@ move_resize_window_internal (GdkWindow *window,
       old_visible.x = -private->x;
       old_visible.y = -private->y;
 
-      gdk_window_get_size (GDK_DRAWABLE (private->parent), 
-                           &old_visible.width, 
-                           &old_visible.height);
+      gdk_drawable_get_size (GDK_DRAWABLE (private->parent),
+                             &old_visible.width,
+                             &old_visible.height);
     }
 
   if (x != -1)
@@ -1404,9 +1410,9 @@ move_resize_window_internal (GdkWindow *window,
           new_visible.width = old_visible.width;   /* parent has not changed size */
           new_visible.height = old_visible.height; /* parent has not changed size */
 
-          expose_region = gdk_region_rectangle (&new_visible);
-          old_region = gdk_region_rectangle (&old_visible);
-          gdk_region_subtract (expose_region, old_region);
+          expose_region = cairo_region_create_rectangle (&new_visible);
+          old_region = cairo_region_create_rectangle (&old_visible);
+          cairo_region_subtract (expose_region, old_region);
 
           /* Determine what (if any) part of the previously visible
            * part of the window can be copied without a redraw
@@ -1416,12 +1422,8 @@ move_resize_window_internal (GdkWindow *window,
           scroll_rect.y -= delta.height;
           gdk_rectangle_intersect (&scroll_rect, &old_visible, &scroll_rect);
 
-          if (!gdk_region_empty (expose_region))
+          if (!cairo_region_is_empty (expose_region))
             {
-              GdkRectangle* rects;
-              gint n_rects;
-              gint n;
-
               if (scroll_rect.width != 0 && scroll_rect.height != 0)
                 {
                   [impl->view scrollRect:NSMakeRect (scroll_rect.x,
@@ -1433,12 +1435,7 @@ move_resize_window_internal (GdkWindow *window,
 
               [impl->view setFrame:nsrect];
 
-              gdk_region_get_rectangles (expose_region, &rects, &n_rects);
-
-              for (n = 0; n < n_rects; ++n)
-                _gdk_quartz_window_set_needs_display_in_rect (window, &rects[n]);
-
-              g_free (rects);
+              _gdk_quartz_window_set_needs_display_in_region (window, expose_region);
             }
           else
             {
@@ -1446,8 +1443,8 @@ move_resize_window_internal (GdkWindow *window,
               [impl->view setNeedsDisplay:YES];
             }
 
-          gdk_region_destroy (expose_region);
-          gdk_region_destroy (old_region);
+          cairo_region_destroy (expose_region);
+          cairo_region_destroy (old_region);
         }
     }
 
@@ -1709,8 +1706,9 @@ gdk_window_quartz_set_back_pixmap (GdkWindow *window,
 }
 
 static void
-gdk_window_quartz_set_cursor (GdkWindow *window,
-                              GdkCursor *cursor)
+gdk_window_quartz_set_device_cursor (GdkWindow *window,
+                                     GdkDevice *device,
+                                     GdkCursor *cursor)
 {
   GdkCursorPrivate *cursor_private;
   NSCursor *nscursor;
@@ -1901,10 +1899,11 @@ gdk_window_get_root_origin (GdkWindow *window,
 
 /* Returns coordinates relative to the passed in window. */
 static GdkWindow *
-gdk_window_quartz_get_pointer_helper (GdkWindow       *window,
-                                      gint            *x,
-                                      gint            *y,
-                                      GdkModifierType *mask)
+gdk_window_quartz_get_device_state_helper (GdkWindow       *window,
+                                           GdkDevice       *device,
+                                           gint            *x,
+                                           gint            *y,
+                                           GdkModifierType *mask)
 {
   GdkWindowObject *toplevel;
   GdkWindowObject *private;
@@ -1922,7 +1921,7 @@ gdk_window_quartz_get_pointer_helper (GdkWindow       *window,
       return NULL;
     }
   
-  toplevel = GDK_WINDOW_OBJECT (gdk_window_get_effective_toplevel (window));
+  toplevel = GDK_WINDOW_OBJECT (gdk_window_get_toplevel (window));
 
   *mask = _gdk_quartz_events_get_current_event_mask ();
 
@@ -1949,7 +1948,8 @@ gdk_window_quartz_get_pointer_helper (GdkWindow       *window,
       window = (GdkWindow *)toplevel;
     }
 
-  found_window = _gdk_quartz_window_find_child (window, x_tmp, y_tmp);
+  found_window = _gdk_quartz_window_find_child (window, x_tmp, y_tmp,
+                                                FALSE);
 
   /* We never return the root window. */
   if (found_window == _gdk_root)
@@ -1962,26 +1962,30 @@ gdk_window_quartz_get_pointer_helper (GdkWindow       *window,
 }
 
 static gboolean
-gdk_window_quartz_get_pointer (GdkWindow       *window,
-                               gint            *x,
-                               gint            *y,
-                               GdkModifierType *mask)
+gdk_window_quartz_get_device_state (GdkWindow       *window,
+                                    GdkDevice       *device,
+                                    gint            *x,
+                                    gint            *y,
+                                    GdkModifierType *mask)
 {
-  return gdk_window_quartz_get_pointer_helper (window, x, y, mask) != NULL;
+  return gdk_window_quartz_get_device_state_helper (window,
+                                                    device,
+                                                    x, y, mask) != NULL;
 }
 
 /* Returns coordinates relative to the root. */
 void
-_gdk_windowing_get_pointer (GdkDisplay       *display,
-                            GdkScreen       **screen,
-                            gint             *x,
-                            gint             *y,
-                            GdkModifierType  *mask)
+_gdk_windowing_get_device_state (GdkDisplay       *display,
+                                 GdkDevice        *device,
+                                 GdkScreen       **screen,
+                                 gint             *x,
+                                 gint             *y,
+                                 GdkModifierType  *mask)
 {
   g_return_if_fail (display == _gdk_display);
   
   *screen = _gdk_screen;
-  gdk_window_quartz_get_pointer_helper (_gdk_root, x, y, mask);
+  gdk_window_quartz_get_device_state_helper (_gdk_root, device, x, y, mask);
 }
 
 void
@@ -2005,9 +2009,10 @@ _gdk_windowing_window_at_pointer (GdkDisplay      *display,
   gint x, y;
   GdkModifierType tmp_mask = 0;
 
-  found_window = gdk_window_quartz_get_pointer_helper (_gdk_root,
-                                                       &x, &y,
-                                                       &tmp_mask);
+  found_window = gdk_window_quartz_get_device_state_helper (_gdk_root,
+                                                            display->core_pointer,
+                                                            &x, &y,
+                                                            &tmp_mask);
   if (found_window)
     {
       GdkWindowObject *private;
@@ -2060,6 +2065,21 @@ _gdk_windowing_window_at_pointer (GdkDisplay      *display,
   return found_window;
 }
 
+GdkWindow*
+_gdk_windowing_window_at_device_position (GdkDisplay      *display,
+                                          GdkDevice       *device,
+                                          gint            *win_x,
+                                          gint            *win_y,
+                                          GdkModifierType *mask,
+                                          gboolean         get_toplevel)
+{
+  return GDK_DEVICE_GET_CLASS (device)->window_at_position (device,
+                                                            win_x, win_y,
+                                                            mask,
+                                                            get_toplevel);
+}
+
+
 static GdkEventMask  
 gdk_window_quartz_get_events (GdkWindow *window)
 {
@@ -2253,7 +2273,7 @@ gdk_window_set_transient_for (GdkWindow *window,
 
 static void
 gdk_window_quartz_shape_combine_region (GdkWindow       *window,
-                                        const GdkRegion *shape,
+                                        const cairo_region_t *shape,
                                         gint             x,
                                         gint             y)
 {
@@ -2262,7 +2282,7 @@ gdk_window_quartz_shape_combine_region (GdkWindow       *window,
 
 static void
 gdk_window_quartz_input_shape_combine_region (GdkWindow       *window,
-                                              const GdkRegion *shape_region,
+                                              const cairo_region_t *shape_region,
                                               gint             offset_x,
                                               gint             offset_y)
 {
@@ -2349,19 +2369,6 @@ gdk_window_focus (GdkWindow *window,
     }
 }
 
-void
-gdk_window_set_hints (GdkWindow *window,
-		      gint       x,
-		      gint       y,
-		      gint       min_width,
-		      gint       min_height,
-		      gint       max_width,
-		      gint       max_height,
-		      gint       flags)
-{
-  /* FIXME: Implement */
-}
-
 static
 gint window_type_hint_to_level (GdkWindowTypeHint hint)
 {
@@ -2579,7 +2586,7 @@ gdk_window_get_frame_extents (GdkWindow    *window,
   rect->width = 1;
   rect->height = 1;
   
-  toplevel = gdk_window_get_effective_toplevel (window);
+  toplevel = gdk_window_get_toplevel (window);
   impl = GDK_WINDOW_IMPL_QUARTZ (GDK_WINDOW_OBJECT (toplevel)->impl);
 
   ns_rect = [impl->toplevel frame];
@@ -2592,14 +2599,6 @@ gdk_window_get_frame_extents (GdkWindow    *window,
   rect->height = ns_rect.size.height;
 }
 
-/* Fake protocol to make gcc think that it's OK to call setStyleMask
-   even if it isn't. We check to make sure before actually calling
-   it. */
-
-@protocol CanSetStyleMask
-- (void)setStyleMask:(int)mask;
-@end
-
 void
 gdk_window_set_decorations (GdkWindow       *window,
 			    GdkWMDecoration  decorations)
@@ -2630,6 +2629,10 @@ gdk_window_set_decorations (GdkWindow       *window,
 
   old_mask = [impl->toplevel styleMask];
 
+  /* Note, there doesn't seem to be a way to change this without
+   * recreating the toplevel. There might be bad side-effects of doing
+   * that, but it seems alright.
+   */
   if (old_mask != new_mask)
     {
       NSRect rect;
@@ -2653,26 +2656,15 @@ gdk_window_set_decorations (GdkWindow       *window,
           rect = [NSWindow contentRectForFrameRect:rect styleMask:old_mask];
         }
 
-      /* Note, before OS 10.6 there doesn't seem to be a way to change this without
-       * recreating the toplevel. There might be bad side-effects of doing
-       * that, but it seems alright.
-       */
-      if ([impl->toplevel respondsToSelector:@selector(setStyleMask:)])
-        {
-          [(id<CanSetStyleMask>)impl->toplevel setStyleMask:new_mask];
-        }
-      else
-        {
-          [impl->toplevel release];
-          impl->toplevel = [[GdkQuartzWindow alloc] initWithContentRect:rect
-                                                                styleMask:new_mask
-                                                                  backing:NSBackingStoreBuffered
-                                                                    defer:NO];
-          [impl->toplevel setHasShadow: window_type_hint_to_shadow (impl->type_hint)];
-          [impl->toplevel setLevel: window_type_hint_to_level (impl->type_hint)];
-          [impl->toplevel setContentView:old_view];
-        }
+      impl->toplevel = [impl->toplevel initWithContentRect:rect
+                                                 styleMask:new_mask
+                                                   backing:NSBackingStoreBuffered
+                                                     defer:NO];
 
+      [impl->toplevel setHasShadow: window_type_hint_to_shadow (impl->type_hint)];
+      [impl->toplevel setLevel: window_type_hint_to_level (impl->type_hint)];
+
+      [impl->toplevel setContentView:old_view];
       [impl->toplevel setFrame:rect display:YES];
 
       /* Invalidate the window shadow for non-opaque views that have shadow
@@ -2725,7 +2717,7 @@ gdk_window_set_functions (GdkWindow    *window,
 
 gboolean
 _gdk_windowing_window_queue_antiexpose (GdkWindow  *window,
-					GdkRegion  *area)
+					cairo_region_t  *area)
 {
   return FALSE;
 }
@@ -3065,21 +3057,21 @@ _gdk_windowing_window_set_composited (GdkWindow *window, gboolean composited)
 {
 }
 
-GdkRegion *
+cairo_region_t *
 _gdk_windowing_get_shape_for_mask (GdkBitmap *mask)
 {
   /* FIXME: implement */
   return NULL;
 }
 
-GdkRegion *
+cairo_region_t *
 _gdk_windowing_window_get_shape (GdkWindow *window)
 {
   /* FIXME: implement */
   return NULL;
 }
 
-GdkRegion *
+cairo_region_t *
 _gdk_windowing_window_get_input_shape (GdkWindow *window)
 {
   /* FIXME: implement */
@@ -3101,10 +3093,10 @@ gdk_window_impl_iface_init (GdkWindowImplIface *iface)
   iface->set_background = gdk_window_quartz_set_background;
   iface->set_back_pixmap = gdk_window_quartz_set_back_pixmap;
   iface->reparent = gdk_window_quartz_reparent;
-  iface->set_cursor = gdk_window_quartz_set_cursor;
+  iface->set_device_cursor = gdk_window_quartz_set_device_cursor;
   iface->get_geometry = gdk_window_quartz_get_geometry;
   iface->get_root_coords = gdk_window_quartz_get_root_coords;
-  iface->get_pointer = gdk_window_quartz_get_pointer;
+  iface->get_device_state = gdk_window_quartz_get_device_state;
   iface->get_deskrelative_origin = gdk_window_quartz_get_deskrelative_origin;
   iface->shape_combine_region = gdk_window_quartz_shape_combine_region;
   iface->input_shape_combine_region = gdk_window_quartz_input_shape_combine_region;
@@ -3112,6 +3104,4 @@ gdk_window_impl_iface_init (GdkWindowImplIface *iface)
   iface->queue_antiexpose = _gdk_quartz_window_queue_antiexpose;
   iface->queue_translation = _gdk_quartz_window_queue_translation;
   iface->destroy = _gdk_quartz_window_destroy;
-  iface->input_window_destroy = _gdk_input_window_destroy;
-  iface->input_window_crossing = _gdk_input_window_crossing;
 }
