@@ -28,7 +28,6 @@
 #include "gdkkeysyms.h"
 #include "gdkprivate-x11.h"
 #include "gdkx.h"
-#include "gdkalias.h"
 
 #define HAS_FOCUS(toplevel) ((toplevel)->has_focus || (toplevel)->has_pointer_focus)
 
@@ -38,6 +37,7 @@ static void    gdk_device_manager_xi2_finalize    (GObject *object);
 
 static GList * gdk_device_manager_xi2_list_devices (GdkDeviceManager *device_manager,
                                                     GdkDeviceType     type);
+static GdkDevice * gdk_device_manager_xi2_get_client_pointer (GdkDeviceManager *device_manager);
 
 static void     gdk_device_manager_xi2_event_translator_init (GdkEventTranslatorIface *iface);
 
@@ -66,6 +66,7 @@ gdk_device_manager_xi2_class_init (GdkDeviceManagerXI2Class *klass)
   object_class->finalize = gdk_device_manager_xi2_finalize;
 
   device_manager_class->list_devices = gdk_device_manager_xi2_list_devices;
+  device_manager_class->get_client_pointer = gdk_device_manager_xi2_get_client_pointer;
 }
 
 static void
@@ -419,6 +420,23 @@ gdk_device_manager_xi2_list_devices (GdkDeviceManager *device_manager,
   return g_list_copy (list);
 }
 
+static GdkDevice *
+gdk_device_manager_xi2_get_client_pointer (GdkDeviceManager *device_manager)
+{
+  GdkDeviceManagerXI2 *device_manager_xi2;
+  GdkDisplay *display;
+  int device_id;
+
+  device_manager_xi2 = (GdkDeviceManagerXI2 *) device_manager;
+  display = gdk_device_manager_get_display (device_manager);
+
+  XIGetClientPointer (GDK_DISPLAY_XDISPLAY (display),
+                      None, &device_id);
+
+  return g_hash_table_lookup (device_manager_xi2->id_table,
+                              GINT_TO_POINTER (device_id));
+}
+
 static void
 gdk_device_manager_xi2_event_translator_init (GdkEventTranslatorIface *iface)
 {
@@ -614,20 +632,24 @@ translate_keyboard_string (GdkEventKey *event)
 
 static void
 generate_focus_event (GdkWindow *window,
-		      gboolean   in)
+                      GdkDevice *device,
+                      gboolean   in)
 {
-  GdkEvent event;
+  GdkEvent *event;
 
-  event.type = GDK_FOCUS_CHANGE;
-  event.focus_change.window = window;
-  event.focus_change.send_event = FALSE;
-  event.focus_change.in = in;
+  event = gdk_event_new (GDK_FOCUS_CHANGE);
+  event->focus_change.window = g_object_ref (window);
+  event->focus_change.send_event = FALSE;
+  event->focus_change.in = in;
+  gdk_event_set_device (event, device);
 
-  gdk_event_put (&event);
+  gdk_event_put (event);
+  gdk_event_free (event);
 }
 
 static void
 handle_focus_change (GdkWindow *window,
+                     GdkDevice *device,
                      gint       detail,
                      gint       mode,
                      gboolean   in)
@@ -687,7 +709,7 @@ handle_focus_change (GdkWindow *window,
     }
 
   if (HAS_FOCUS (toplevel) != had_focus)
-    generate_focus_event (window, (in) ? TRUE : FALSE);
+    generate_focus_event (window, device, (in) ? TRUE : FALSE);
 }
 
 static gdouble *
@@ -1071,8 +1093,12 @@ gdk_device_manager_xi2_translate_event (GdkEventTranslator *translator,
     case XI_FocusOut:
       {
         XIEnterEvent *xev = (XIEnterEvent *) ev;
+        GdkDevice *device;
 
-        handle_focus_change (window, xev->detail, xev->mode,
+        device = g_hash_table_lookup (device_manager->id_table,
+                                      GINT_TO_POINTER (xev->deviceid));
+
+        handle_focus_change (window, device, xev->detail, xev->mode,
                              (ev->evtype == XI_FocusIn) ? TRUE : FALSE);
 
         return_val = FALSE;
@@ -1141,6 +1167,3 @@ gdk_device_manager_xi2_select_window_events (GdkEventTranslator *translator,
   _gdk_device_manager_xi2_select_events (device_manager, window, &event_mask);
   g_free (event_mask.mask);
 }
-
-#define __GDK_DEVICE_MANAGER_XI2_C__
-#include "gdkaliasdef.c"
