@@ -42,7 +42,6 @@
 #include "gdkdeviceprivate.h"
 #include "gdkdevicemanager.h"
 #include "xsettings-client.h"
-#include "gdkalias.h"
 
 #include <X11/Xatom.h>
 
@@ -2498,7 +2497,7 @@ gdk_display_supports_composite (GdkDisplay *display)
  *
  * Since: 2.2
  *
- * Deprecated: 3.0. Use gdk_device_manager_list_devices() instead.
+ * Deprecated: 3.0: Use gdk_device_manager_list_devices() instead.
  **/
 GList *
 gdk_display_list_devices (GdkDisplay *display)
@@ -2666,6 +2665,3 @@ gdk_x11_register_standard_event_type (GdkDisplay *display,
 
   display_x11->event_types = g_slist_prepend (display_x11->event_types, event_type);
 }
-
-#define __GDK_DISPLAY_X11_C__
-#include "gdkaliasdef.c"
