@@ -36,7 +36,6 @@
 #include "gtkkeyhash.h"
 #include "gtkwidget.h"
 #include "gtkrc.h"
-#include "gtkalias.h"
 
 
 /* --- defines --- */
@@ -706,37 +705,6 @@ gtk_binding_entry_clear_internal (GtkBindingSet  *binding_set,
   entry = binding_entry_new (binding_set, keyval, modifiers);
 }
 
-/**
- * gtk_binding_entry_add:
- * @binding_set: #a GtkBindingSet to clear an entry of
- * @keyval:      key value of binding to clear
- * @modifiers:   key modifier of binding to clear
- *
- * Adds a binding entry.
- *
- * Deprecated: 2.12: Use gtk_binding_entry_add_signal() instead.
- */
-
-/**
- * gtk_binding_entry_clear:
- * @binding_set: binding set to clear an entry of
- * @keyval:      key value of binding to clear
- * @modifiers:   key modifier of binding to clear
- *
- * Clears a binding entry.
- *
- * Deprecated: 2.12: Use gtk_binding_entry_remove() instead.
- */
-void
-gtk_binding_entry_clear (GtkBindingSet	*binding_set,
-			 guint		 keyval,
-			 GdkModifierType modifiers)
-{
-  g_return_if_fail (binding_set != NULL);
-
-  gtk_binding_entry_clear_internal (binding_set, keyval, modifiers);
-}
-
 /**
  * gtk_binding_entry_skip:
  * @binding_set: a #GtkBindingSet to skip an entry of
@@ -1334,6 +1302,8 @@ gtk_bindings_activate (GtkObject       *object,
  * @event, and if one was found, activate it.
  * 
  * Return value: %TRUE if a matching key binding was found
+ *
+ * Since: 2.4
  */
 gboolean
 gtk_bindings_activate_event (GtkObject   *object,
@@ -1586,22 +1556,6 @@ gtk_binding_parse_bind (GScanner       *scanner,
   return G_TOKEN_NONE;
 }
 
-/**
- * gtk_binding_parse_binding:
- * @scanner: GtkRC scanner
- *
- * Parse a binding entry from a gtkrc file.
- *
- * Return value: expected token upon errors, %G_TOKEN_NONE on success.
- *
- * Deprecated: 2.12: There should be no need to call this function outside GTK+.
- */
-guint
-gtk_binding_parse_binding (GScanner *scanner)
-{
-  return _gtk_binding_parse_binding (scanner);
-}
-
 guint
 _gtk_binding_parse_binding (GScanner *scanner)
 {
@@ -1721,6 +1675,3 @@ _gtk_binding_reset_parsed (void)
       slist = next;
     }
 }
-
-#define __GTK_BINDINGS_C__
-#include "gtkaliasdef.c"
