@@ -26,7 +26,7 @@
 #include "gtkintl.h"
 #include "gtkprivate.h"
 #include "gtktreeprivate.h"
-#include "gtkalias.h"
+
 
 static void gtk_cell_renderer_text_finalize   (GObject                  *object);
 
@@ -1023,7 +1023,7 @@ gtk_cell_renderer_text_set_property (GObject      *object,
           priv->markup_set = FALSE;
         }
 
-      celltext->text = g_strdup (g_value_get_string (value));
+      celltext->text = g_value_dup_string (value);
       g_object_notify (object, "text");
       break;
 
@@ -1636,19 +1636,19 @@ gtk_cell_renderer_text_render (GtkCellRenderer      *cell,
     }
   else if ((flags & GTK_CELL_RENDERER_SELECTED) == GTK_CELL_RENDERER_SELECTED)
     {
-      if (GTK_WIDGET_HAS_FOCUS (widget))
+      if (gtk_widget_has_focus (widget))
 	state = GTK_STATE_SELECTED;
       else
 	state = GTK_STATE_ACTIVE;
     }
   else if ((flags & GTK_CELL_RENDERER_PRELIT) == GTK_CELL_RENDERER_PRELIT &&
-	   GTK_WIDGET_STATE (widget) == GTK_STATE_PRELIGHT)
+	   gtk_widget_get_state (widget) == GTK_STATE_PRELIGHT)
     {
       state = GTK_STATE_PRELIGHT;
     }
   else
     {
-      if (GTK_WIDGET_STATE (widget) == GTK_STATE_INSENSITIVE)
+      if (gtk_widget_get_state (widget) == GTK_STATE_INSENSITIVE)
 	state = GTK_STATE_INSENSITIVE;
       else
 	state = GTK_STATE_NORMAL;
@@ -1701,6 +1701,7 @@ gtk_cell_renderer_text_editing_done (GtkCellEditable *entry,
 {
   const gchar *path;
   const gchar *new_text;
+  gboolean canceled;
   GtkCellRendererTextPrivate *priv;
 
   priv = GTK_CELL_RENDERER_TEXT_GET_PRIVATE (data);
@@ -1725,9 +1726,12 @@ gtk_cell_renderer_text_editing_done (GtkCellEditable *entry,
       priv->entry_menu_popdown_timeout = 0;
     }
 
-  gtk_cell_renderer_stop_editing (GTK_CELL_RENDERER (data), 
-				  GTK_ENTRY (entry)->editing_canceled);
-  if (GTK_ENTRY (entry)->editing_canceled)
+  g_object_get (entry,
+                "editing-canceled", &canceled,
+                NULL);
+  gtk_cell_renderer_stop_editing (GTK_CELL_RENDERER (data), canceled);
+
+  if (canceled)
     return;
 
   path = g_object_get_data (G_OBJECT (entry), GTK_CELL_RENDERER_TEXT_PATH);
@@ -1745,7 +1749,7 @@ popdown_timeout (gpointer data)
 
   priv->entry_menu_popdown_timeout = 0;
 
-  if (!GTK_WIDGET_HAS_FOCUS (priv->entry))
+  if (!gtk_widget_has_focus (priv->entry))
     gtk_cell_renderer_text_editing_done (GTK_CELL_EDITABLE (priv->entry), data);
 
   return FALSE;
@@ -1801,7 +1805,9 @@ gtk_cell_renderer_text_focus_out_event (GtkWidget *entry,
   if (priv->in_entry_menu)
     return FALSE;
 
-  GTK_ENTRY (entry)->editing_canceled = TRUE;
+  g_object_set (entry,
+                "editing-canceled", TRUE,
+                NULL);
   gtk_cell_editable_editing_done (GTK_CELL_EDITABLE (entry));
   gtk_cell_editable_remove_widget (GTK_CELL_EDITABLE (entry));
 
@@ -1923,6 +1929,3 @@ gtk_cell_renderer_text_set_fixed_height_from_font (GtkCellRendererText *renderer
       renderer->calc_fixed_height = TRUE;
     }
 }
-
-#define __GTK_CELL_RENDERER_TEXT_C__
-#include "gtkaliasdef.c"
