@@ -28,7 +28,6 @@
 #include "gtkprivate.h"
 #include "gtkintl.h"
 #include "gtkbuildable.h"
-#include "gtkalias.h"
 
 #define GTK_COMBO_BOX_ENTRY_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GTK_TYPE_COMBO_BOX_ENTRY, GtkComboBoxEntryPrivate))
 
@@ -461,6 +460,3 @@ gtk_combo_box_entry_get_active_text (GtkComboBox *combo_box)
 
   return NULL;
 }
-
-#define __GTK_COMBO_BOX_ENTRY_C__
-#include "gtkaliasdef.c"
