@@ -40,7 +40,6 @@
 #include "gtktoolbar.h"
 #include <gobject/gobjectnotifyqueue.c>
 #include <gobject/gvaluecollector.h>
-#include "gtkalias.h"
 
 
 enum {
@@ -1530,14 +1529,6 @@ gtk_container_foreach (GtkContainer *container,
     class->forall (container, FALSE, callback, callback_data);
 }
 
-typedef struct _GtkForeachData	GtkForeachData;
-struct _GtkForeachData
-{
-  GtkObject         *container;
-  GtkCallbackMarshal callback;
-  gpointer           callback_data;
-};
-
 /**
  * gtk_container_set_focus_child:
  * @container: a #GtkContainer
@@ -2684,14 +2675,11 @@ gtk_container_propagate_expose (GtkContainer   *container,
       g_object_ref (child_event->expose.window);
 
       child_event->expose.region = gtk_widget_region_intersect (child, event->region);
-      if (!gdk_region_empty (child_event->expose.region))
+      if (!cairo_region_is_empty (child_event->expose.region))
 	{
-	  gdk_region_get_clipbox (child_event->expose.region, &child_event->expose.area);
+	  cairo_region_get_extents (child_event->expose.region, &child_event->expose.area);
 	  gtk_widget_send_expose (child, child_event);
 	}
       gdk_event_free (child_event);
     }
 }
-
-#define __GTK_CONTAINER_C__
-#include "gtkaliasdef.c"
