@@ -28,7 +28,8 @@
 #include "gtkfixed.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
-#include "gtkalias.h"
+
+
 enum {
   CHILD_PROP_0,
   CHILD_PROP_X,
@@ -452,6 +453,3 @@ gtk_fixed_forall (GtkContainer *container,
       (* callback) (child->widget, callback_data);
     }
 }
-
-#define __GTK_FIXED_C__
-#include "gtkaliasdef.c"
