@@ -53,7 +53,6 @@
 #include "gtkicontheme.h"
 #include "gtkimagemenuitem.h"
 #include "gtkmain.h"
-#include "gtkalias.h"
 
 /**
  * SECTION:filesystem
@@ -878,7 +877,7 @@ add_pid_to_process_list_store (GtkMountOperation              *mount_operation,
                                     &pixbuf);
 
   if (name == NULL)
-    name = g_strdup_printf (_("Unknown Application (PID %d)"), pid);
+    name = g_strdup_printf (_("Unknown Application (pid %d)"), pid);
 
   if (command_line == NULL)
     command_line = g_strdup ("");
@@ -1525,6 +1524,3 @@ gtk_mount_operation_get_screen (GtkMountOperation *op)
   else
     return gdk_screen_get_default ();
 }
-
-#define __GTK_MOUNT_OPERATION_C__
-#include "gtkaliasdef.c"
