@@ -54,7 +54,20 @@
 #include "gtkprintbackend.h"
 #include "gtkpapersize.h"
 #include "gtkprintutils.h"
-#include "gtkalias.h"
+
+/**
+ * SECTION:gtkpagesetupunixdialog
+ * @Short_description: A page setup dialog
+ * @Title: GtkPageSetupUnixDialog
+ *
+ * #GtkPageSetupUnixDialog implements a page setup dialog for platforms
+ * which don't provide a native page setup dialog, like Unix. It can
+ * be used very much like any other GTK+ dialog, at the cost of
+ * the portability offered by the <link
+ * linkend="gtk-High-level-Printing-API">high-level printing API</link>
+ *
+ * Printing support was added in GTK+ 2.10.
+ */
 
 
 struct GtkPageSetupUnixDialogPrivate
@@ -992,8 +1005,8 @@ populate_dialog (GtkPageSetupUnixDialog *ps_dialog)
 
 /**
  * gtk_page_setup_unix_dialog_new:
- * @title: the title of the dialog, or %NULL
- * @parent: transient parent of the dialog, or %NULL
+ * @title: (allow-none): the title of the dialog, or %NULL
+ * @parent: (allow-none): transient parent of the dialog, or %NULL
  *
  * Creates a new page setup dialog.
  *
@@ -1192,6 +1205,3 @@ gtk_page_setup_unix_dialog_get_print_settings (GtkPageSetupUnixDialog *dialog)
 
   return priv->print_settings;
 }
-
-#define __GTK_PAGE_SETUP_UNIX_DIALOG_C__
-#include "gtkaliasdef.c"
