@@ -28,7 +28,6 @@
 #include "gtkmarshalers.h"
 #include "gtkprivate.h"
 #include "gtkprintbackend.h"
-#include "gtkalias.h"
 
 #define GTK_PRINT_BACKEND_GET_PRIVATE(o)  \
    (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTK_TYPE_PRINT_BACKEND, GtkPrintBackendPrivate))
@@ -303,6 +302,11 @@ _gtk_print_backend_create (const gchar *backend_name)
   return pb;
 }
 
+/**
+ * gtk_printer_backend_load_modules:
+ *
+ * Return value: (element-type GtkPrintBackend) (transfer container):
+ */
 GList *
 gtk_print_backend_load_modules (void)
 {
@@ -348,11 +352,11 @@ G_DEFINE_TYPE (GtkPrintBackend, gtk_print_backend, G_TYPE_OBJECT)
 static void                 fallback_printer_request_details       (GtkPrinter          *printer);
 static gboolean             fallback_printer_mark_conflicts        (GtkPrinter          *printer,
 								    GtkPrinterOptionSet *options);
-static void                 fallback_printer_get_hard_margins      (GtkPrinter          *printer,
-								    gdouble             *top,
-								    gdouble             *bottom,
-								    gdouble             *left,
-								    gdouble             *right);
+static gboolean             fallback_printer_get_hard_margins      (GtkPrinter          *printer,
+                                                                    gdouble             *top,
+                                                                    gdouble             *bottom,
+                                                                    gdouble             *left,
+                                                                    gdouble             *right);
 static GList *              fallback_printer_list_papers           (GtkPrinter          *printer);
 static GtkPageSetup *       fallback_printer_get_default_page_size (GtkPrinter          *printer);
 static GtkPrintCapabilities fallback_printer_get_capabilities      (GtkPrinter          *printer);
@@ -493,17 +497,14 @@ fallback_printer_mark_conflicts (GtkPrinter          *printer,
   return FALSE;
 }
 
-static void
+static gboolean
 fallback_printer_get_hard_margins (GtkPrinter *printer,
 				   gdouble    *top,
 				   gdouble    *bottom,
 				   gdouble    *left,
 				   gdouble    *right)
 {
-  *top = 0;
-  *bottom = 0;
-  *left = 0;
-  *right = 0;
+  return FALSE;
 }
 
 static GList *
@@ -589,6 +590,11 @@ gtk_print_backend_set_list_done (GtkPrintBackend *backend)
 }
 
 
+/**
+ * gtk_print_backend_get_printer_list:
+ *
+ * Return value: (element-type GtkPrinter) (transfer container):
+ */
 GList *
 gtk_print_backend_get_printer_list (GtkPrintBackend *backend)
 {
@@ -830,7 +836,3 @@ gtk_print_backend_destroy (GtkPrintBackend *print_backend)
    */
   g_object_run_dispose (G_OBJECT (print_backend));
 }
-
-
-#define __GTK_PRINT_BACKEND_C__
-#include "gtkaliasdef.c"
