@@ -29,6 +29,7 @@
 #include "gtkcelllayout.h"
 #include "gtkcellrenderertext.h"
 #include "gtkcombobox.h"
+#include "gtkcomboboxentry.h"
 #include "gtkfilechooserbutton.h"
 #include "gtkimage.h"
 #include "gtklabel.h"
@@ -40,7 +41,6 @@
 #include "gtkprivate.h"
 
 #include "gtkprinteroptionwidget.h"
-#include "gtkalias.h"
 
 #define GTK_PRINTER_OPTION_WIDGET_GET_PRIVATE(o)  \
    (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTK_TYPE_PRINTER_OPTION_WIDGET, GtkPrinterOptionWidgetPrivate))
@@ -287,11 +287,11 @@ static GtkWidget *
 combo_box_entry_new (void)
 {
   GtkWidget *combo_box;
-  combo_box = g_object_new (GTK_TYPE_COMBO_BOX, "has-entry", TRUE, NULL);
+  combo_box = gtk_combo_box_entry_new ();
 
   combo_box_set_model (combo_box);
 
-  gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (combo_box), NAME_COLUMN);
+  gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo_box), NAME_COLUMN);
 
   return combo_box;
 }
@@ -373,7 +373,7 @@ combo_box_get (GtkWidget *combo)
   gchar *value;
   GtkTreeIter iter;
 
-  if (gtk_combo_box_get_has_entry (GTK_COMBO_BOX (combo)))
+  if (GTK_IS_COMBO_BOX_ENTRY (combo))
     {
       value = gtk_combo_box_get_active_text(GTK_COMBO_BOX (combo));
     }
@@ -791,7 +791,7 @@ construct_widgets (GtkPrinterOptionWidget *widget)
 
         /* TODO: make this a gtkfilechooserentry once we move to GTK */
         priv->entry = gtk_entry_new ();
-        priv->combo = gtk_file_chooser_button_new (source->display_text,
+        priv->combo = gtk_file_chooser_button_new (_("Select a folder"),
                                                    GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 
         g_object_set (priv->combo, "local-only", FALSE, NULL);
@@ -926,6 +926,3 @@ gtk_printer_option_widget_get_value (GtkPrinterOptionWidget *widget)
   
   return "";
 }
-
-#define __GTK_PRINTER_OPTION_WIDGET_C__
-#include "gtkaliasdef.c"
