@@ -28,9 +28,9 @@
 #include "gtkaccellabel.h"
 #include "gtkmarshalers.h"
 #include "gtkradiomenuitem.h"
+#include "gtkactivatable.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
-#include "gtkalias.h"
 
 
 enum {
@@ -179,6 +179,16 @@ gtk_radio_menu_item_set_group (GtkRadioMenuItem *radio_menu_item,
   g_object_unref (radio_menu_item);
 }
 
+
+/**
+ * gtk_radio_menu_item_new_with_label:
+ * @group: (element-type GtkRadioMenuItem) (transfer full):
+ * @label: the text for the label
+ *
+ * Creates a new #GtkRadioMenuItem whose child is a simple #GtkLabel.
+ *
+ * Returns: (transfer none): A new #GtkRadioMenuItem
+ */
 GtkWidget*
 gtk_radio_menu_item_new_with_label (GSList *group,
 				    const gchar *label)
@@ -410,9 +420,8 @@ gtk_radio_menu_item_destroy (GtkObject *object)
     g_signal_emit (old_group_singleton, group_changed_signal, 0);
   if (was_in_group)
     g_signal_emit (radio_menu_item, group_changed_signal, 0);
-  
-  if (GTK_OBJECT_CLASS (gtk_radio_menu_item_parent_class)->destroy)
-    (* GTK_OBJECT_CLASS (gtk_radio_menu_item_parent_class)->destroy) (object);
+
+  GTK_OBJECT_CLASS (gtk_radio_menu_item_parent_class)->destroy (object);
 }
 
 static void
@@ -421,9 +430,14 @@ gtk_radio_menu_item_activate (GtkMenuItem *menu_item)
   GtkRadioMenuItem *radio_menu_item = GTK_RADIO_MENU_ITEM (menu_item);
   GtkCheckMenuItem *check_menu_item = GTK_CHECK_MENU_ITEM (menu_item);
   GtkCheckMenuItem *tmp_menu_item;
+  GtkAction        *action;
   GSList *tmp_list;
   gint toggled;
 
+  action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (menu_item));
+  if (action && gtk_menu_item_get_submenu (menu_item) == NULL)
+    gtk_action_activate (action);
+
   toggled = FALSE;
 
   if (check_menu_item->active)
@@ -468,10 +482,9 @@ gtk_radio_menu_item_activate (GtkMenuItem *menu_item)
     }
 
   if (toggled)
-    gtk_check_menu_item_toggled (check_menu_item);
+    {
+      gtk_check_menu_item_toggled (check_menu_item);
+    }
 
   gtk_widget_queue_draw (GTK_WIDGET (radio_menu_item));
 }
-
-#define __GTK_RADIO_MENU_ITEM_C__
-#include "gtkaliasdef.c"
