@@ -25,7 +25,7 @@
 #include "gtkradiobutton.h"
 #include "gtkintl.h"
 #include "gtkprivate.h"
-#include "gtkalias.h"
+
 
 enum {
   PROP_0,
@@ -62,8 +62,8 @@ gtk_radio_tool_button_class_init (GtkRadioToolButtonClass *klass)
   g_object_class_install_property (object_class,
 				   PROP_GROUP,
 				   g_param_spec_object ("group",
-							_("Group"),
-							_("The radio tool button whose group this button belongs to."),
+							P_("Group"),
+							P_("The radio tool button whose group this button belongs to."),
 							GTK_TYPE_RADIO_TOOL_BUTTON,
 							GTK_PARAM_WRITABLE));
 
@@ -109,7 +109,7 @@ gtk_radio_tool_button_set_property (GObject         *object,
 
 /**
  * gtk_radio_tool_button_new:
- * @group: An existing radio button group, or %NULL if you are creating a new group
+ * @group: (allow-none): An existing radio button group, or %NULL if you are creating a new group
  * 
  * Creates a new #GtkRadioToolButton, adding it to @group.
  * 
@@ -132,7 +132,7 @@ gtk_radio_tool_button_new (GSList *group)
 
 /**
  * gtk_radio_tool_button_new_from_stock:
- * @group: an existing radio button group, or %NULL if you are creating a new group
+ * @group: (allow-none): an existing radio button group, or %NULL if you are creating a new group
  * @stock_id: the name of a stock item
  * 
  * Creates a new #GtkRadioToolButton, adding it to @group. 
@@ -252,6 +252,3 @@ gtk_radio_tool_button_set_group (GtkRadioToolButton *button,
 
   gtk_radio_button_set_group (get_radio_button (button), group);
 }
-
-#define __GTK_RADIO_TOOL_BUTTON_C__
-#include "gtkaliasdef.c"
