@@ -30,12 +30,11 @@
 #include "gtkscrollbar.h"
 #include "gtkintl.h"
 #include "gtkprivate.h"
-#include "gtkalias.h"
 
 static void gtk_scrollbar_style_set (GtkWidget *widget,
                                      GtkStyle  *previous);
 
-G_DEFINE_ABSTRACT_TYPE (GtkScrollbar, gtk_scrollbar, GTK_TYPE_RANGE)
+G_DEFINE_TYPE (GtkScrollbar, gtk_scrollbar, GTK_TYPE_RANGE)
 
 static void
 gtk_scrollbar_class_init (GtkScrollbarClass *class)
@@ -125,17 +124,16 @@ gtk_scrollbar_style_set (GtkWidget *widget,
   GTK_WIDGET_CLASS (gtk_scrollbar_parent_class)->style_set (widget, previous);
 }
 
-#if 0
 /**
  * gtk_scrollbar_new:
  * @orientation: the scrollbar's orientation.
- * @adjustment: the #GtkAdjustment to use, or %NULL to create a new adjustment.
+ * @adjustment: (allow-none): the #GtkAdjustment to use, or %NULL to create a new adjustment.
  *
  * Creates a new scrollbar with the given orientation.
  *
  * Return value:  the new #GtkScrollbar.
  *
- * Since: 2.16
+ * Since: 3.0
  **/
 GtkWidget *
 gtk_scrollbar_new (GtkOrientation  orientation,
@@ -149,8 +147,3 @@ gtk_scrollbar_new (GtkOrientation  orientation,
                        "adjustment",  adjustment,
                        NULL);
 }
-#endif
-
-
-#define __GTK_SCROLLBAR_C__
-#include "gtkaliasdef.c"
