@@ -19,15 +19,31 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#undef GTK_DISABLE_DEPRECATED
-
-#include <config.h>
+#include "config.h"
 #include "gtkseparatormenuitem.h"
 #include "gtkseparatortoolitem.h"
 #include "gtkintl.h"
 #include "gtktoolbar.h"
 #include "gtkprivate.h"
-#include "gtkalias.h"
+
+/**
+ * SECTION:gtkseparatortoolitem
+ * @Short_description: A toolbar item that separates groups of other
+ *   toolbar items
+ * @Title: GtkSeparatorToolItem
+ * @See_also: #GtkToolbar, #GtkRadioToolButton
+ *
+ * A #GtkSeparatorItem is a #GtkToolItem that separates groups of other
+ * #GtkToolItems. Depending on the theme, a #GtkSeparatorToolItem will
+ * often look like a vertical line on horizontally docked toolbars.
+ *
+ * If the #GtkToolbar child property "expand" is %TRUE and the property
+ * #GtkSeparatorToolItem:draw is %FALSE, a #GtkSeparatorToolItem will act as
+ * a "spring" that forces other items to the ends of the toolbar.
+ *
+ * Use gtk_separator_tool_item_new() to create a new #GtkSeparatorToolItem.
+ */
+
 
 #define MENU_ID "gtk-separator-tool-item-menu-id"
 
@@ -223,7 +239,7 @@ gtk_separator_tool_item_expose (GtkWidget      *widget,
  * Return value: the new #GtkSeparatorToolItem
  * 
  * Since: 2.4
- **/
+ */
 GtkToolItem *
 gtk_separator_tool_item_new (void)
 {
@@ -239,13 +255,13 @@ gtk_separator_tool_item_new (void)
  * gtk_separator_tool_item_get_draw:
  * @item: a #GtkSeparatorToolItem 
  * 
- * Returns whether @separator_tool_item is drawn as a
- * line, or just blank. See gtk_separator_tool_item_set_draw().
+ * Returns whether @item is drawn as a line, or just blank. 
+ * See gtk_separator_tool_item_set_draw().
  * 
- * Return value: #TRUE if @separator_tool_item is drawn as a line, or just blank.
+ * Return value: %TRUE if @item is drawn as a line, or just blank.
  * 
  * Since: 2.4
- **/
+ */
 gboolean
 gtk_separator_tool_item_get_draw (GtkSeparatorToolItem *item)
 {
@@ -257,14 +273,14 @@ gtk_separator_tool_item_get_draw (GtkSeparatorToolItem *item)
 /**
  * gtk_separator_tool_item_set_draw:
  * @item: a #GtkSeparatorToolItem
- * @draw: whether @separator_tool_item is drawn as a vertical line
+ * @draw: whether @item is drawn as a vertical line
  * 
- * When @separator_tool_items is drawn as a vertical line, or just blank.
- * Setting this #FALSE along with gtk_tool_item_set_expand() is useful
+ * Whether @item is drawn as a vertical line, or just blank.
+ * Setting this to %FALSE along with gtk_tool_item_set_expand() is useful
  * to create an item that forces following items to the end of the toolbar.
  * 
  * Since: 2.4
- **/
+ */
 void
 gtk_separator_tool_item_set_draw (GtkSeparatorToolItem *item,
 				  gboolean              draw)
@@ -282,6 +298,3 @@ gtk_separator_tool_item_set_draw (GtkSeparatorToolItem *item,
       g_object_notify (G_OBJECT (item), "draw");
     }
 }
-
-#define __GTK_SEPARATOR_TOOL_ITEM_C__
-#include "gtkaliasdef.c"
