@@ -32,7 +32,6 @@
 #include "gtkiconfactory.h"
 #include "gtkintl.h"
 #include <gdk/gdkkeysyms.h>
-#include "gtkalias.h"
 
 /**
  * SECTION:gtkstock
@@ -51,7 +50,7 @@ Prebuilt common menu/toolbar items and corresponding icons
  * the user-visible label, keyboard accelerator, and translation domain
  * of the menu or toolbar item; and/or with an icon stored in a
  * #GtkIconFactory. See <link
- * linkend="gtk-Themeable-Stock-Images">GtkIconFactory</link> for
+ * linkend="gtk3-Themeable-Stock-Images">GtkIconFactory</link> for
  * more information on stock icons. The connection between a
  * #GtkStockItem and stock icons is purely conventional (by virtue of
  * using the same stock ID); it's possible to register a stock item but
@@ -123,7 +122,7 @@ real_add (const GtkStockItem *items,
 
 /**
  * gtk_stock_add:
- * @items: (array length=n_items): a #GtkStockItem or array of items
+ * @items: a #GtkStockItem or array of items
  * @n_items: number of #GtkStockItem in @items
  *
  * Registers each of the stock items in @items. If an item already
@@ -145,7 +144,7 @@ gtk_stock_add (const GtkStockItem *items,
 
 /**
  * gtk_stock_add_static:
- * @items: (array length=n_items): a #GtkStockItem or array of #GtkStockItem
+ * @items: a #GtkStockItem or array of #GtkStockItem
  * @n_items: number of items
  *
  * Same as gtk_stock_add(), but doesn't copy @items, so
@@ -164,7 +163,7 @@ gtk_stock_add_static (const GtkStockItem *items,
 /**
  * gtk_stock_lookup:
  * @stock_id: a stock item name
- * @item: (out): stock item to initialize with values
+ * @item: stock item to initialize with values
  * 
  * Fills @item with the registered values for @stock_id, returning %TRUE
  * if @stock_id was known.
@@ -553,6 +552,3 @@ init_stock_hash (void)
 				    NULL);
     }
 }
-
-#define __GTK_STOCK_C__
-#include "gtkaliasdef.c"
