@@ -117,7 +117,6 @@ struct _GtkStyle
 
   gint depth;
   GdkColormap *colormap;
-  GdkFont *private_font;
   PangoFontDescription *private_font_desc; /* Font description for style->private_font or %NULL */
 
   /* the RcStyle from which this style was created */
@@ -240,15 +239,6 @@ struct _GtkStyleClass
 				 gint			 y,
 				 gint			 width,
 				 gint			 height);
-  void (*draw_string)		(GtkStyle		*style,
-				 GdkWindow		*window,
-				 GtkStateType		 state_type,
-				 GdkRectangle		*area,
-				 GtkWidget		*widget,
-				 const gchar		*detail,
-				 gint			 x,
-				 gint			 y,
-				 const gchar		*string);
   void (*draw_box)		(GtkStyle		*style,
 				 GdkWindow		*window,
 				 GtkStateType		 state_type,
