@@ -28,7 +28,7 @@
 #include "gtktable.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
-#include "gtkalias.h"
+
 
 enum
 {
@@ -129,7 +129,7 @@ gtk_table_class_init (GtkTableClass *class)
 						     P_("Rows"),
 						     P_("The number of rows in the table"),
 						     1,
-						     G_MAXUINT,
+						     65535,
 						     1,
 						     GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
@@ -138,7 +138,7 @@ gtk_table_class_init (GtkTableClass *class)
 						     P_("Columns"),
 						     P_("The number of columns in the table"),
 						     1,
-						     G_MAXUINT,
+						     65535,
 						     1,
 						     GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
@@ -147,7 +147,7 @@ gtk_table_class_init (GtkTableClass *class)
 						     P_("Row spacing"),
 						     P_("The amount of space between two consecutive rows"),
 						     0,
-						     G_MAXUINT,
+						     65535,
 						     0,
 						     GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
@@ -156,7 +156,7 @@ gtk_table_class_init (GtkTableClass *class)
 						     P_("Column spacing"),
 						     P_("The amount of space between two consecutive columns"),
 						     0,
-						     G_MAXUINT,
+						     65535,
 						     0,
 						     GTK_PARAM_READWRITE));
   g_object_class_install_property (gobject_class,
@@ -372,7 +372,8 @@ gtk_table_set_child_property (GtkContainer    *container,
       GTK_CONTAINER_WARN_INVALID_CHILD_PROPERTY_ID (container, property_id, pspec);
       break;
     }
-  if (GTK_WIDGET_VISIBLE (child) && GTK_WIDGET_VISIBLE (table))
+  if (gtk_widget_get_visible (child) &&
+      gtk_widget_get_visible (GTK_WIDGET (table)))
     gtk_widget_queue_resize (child);
 }
 
@@ -440,7 +441,7 @@ gtk_table_get_child_property (GtkContainer    *container,
 static void
 gtk_table_init (GtkTable *table)
 {
-  GTK_WIDGET_SET_FLAGS (table, GTK_NO_WINDOW);
+  gtk_widget_set_has_window (GTK_WIDGET (table), FALSE);
   gtk_widget_set_redraw_on_allocate (GTK_WIDGET (table), FALSE);
   
   table->children = NULL;
@@ -482,8 +483,8 @@ gtk_table_resize (GtkTable *table,
 		  guint     n_cols)
 {
   g_return_if_fail (GTK_IS_TABLE (table));
-  g_return_if_fail (n_rows > 0 && n_rows < 65536);
-  g_return_if_fail (n_cols > 0 && n_cols < 65536);
+  g_return_if_fail (n_rows > 0 && n_rows <= 65535);
+  g_return_if_fail (n_cols > 0 && n_cols <= 65535);
 
   n_rows = MAX (n_rows, 1);
   n_cols = MAX (n_cols, 1);
@@ -626,7 +627,7 @@ gtk_table_set_row_spacing (GtkTable *table,
     {
       table->rows[row].spacing = spacing;
       
-      if (GTK_WIDGET_VISIBLE (table))
+      if (gtk_widget_get_visible (GTK_WIDGET (table)))
 	gtk_widget_queue_resize (GTK_WIDGET (table));
     }
 }
@@ -663,7 +664,7 @@ gtk_table_set_col_spacing (GtkTable *table,
     {
       table->cols[column].spacing = spacing;
       
-      if (GTK_WIDGET_VISIBLE (table))
+      if (gtk_widget_get_visible (GTK_WIDGET (table)))
 	gtk_widget_queue_resize (GTK_WIDGET (table));
     }
 }
@@ -700,7 +701,7 @@ gtk_table_set_row_spacings (GtkTable *table,
   for (row = 0; row < table->nrows; row++)
     table->rows[row].spacing = spacing;
   
-  if (GTK_WIDGET_VISIBLE (table))
+  if (gtk_widget_get_visible (GTK_WIDGET (table)))
     gtk_widget_queue_resize (GTK_WIDGET (table));
 
   g_object_notify (G_OBJECT (table), "row-spacing");
@@ -736,7 +737,7 @@ gtk_table_set_col_spacings (GtkTable *table,
   for (col = 0; col < table->ncols; col++)
     table->cols[col].spacing = spacing;
   
-  if (GTK_WIDGET_VISIBLE (table))
+  if (gtk_widget_get_visible (GTK_WIDGET (table)))
     gtk_widget_queue_resize (GTK_WIDGET (table));
 
   g_object_notify (G_OBJECT (table), "column-spacing");
@@ -771,7 +772,7 @@ gtk_table_set_homogeneous (GtkTable *table,
     {
       table->homogeneous = homogeneous;
       
-      if (GTK_WIDGET_VISIBLE (table))
+      if (gtk_widget_get_visible (GTK_WIDGET (table)))
 	gtk_widget_queue_resize (GTK_WIDGET (table));
 
       g_object_notify (G_OBJECT (table), "homogeneous");
@@ -795,6 +796,32 @@ gtk_table_get_homogeneous (GtkTable *table)
   return table->homogeneous;
 }
 
+/**
+ * gtk_table_get_size:
+ * @table: a #GtkTable
+ * @rows: (out) (allow-none): return location for the number of
+ *   rows, or %NULL
+ * @columns: (out) (allow-none): return location for the number
+ *   of columns, or %NULL
+ *
+ * Returns the number of rows and columns in the table.
+ *
+ * Since: 2.22
+ **/
+void
+gtk_table_get_size (GtkTable *table,
+                    guint    *rows,
+                    guint    *columns)
+{
+  g_return_if_fail (GTK_IS_TABLE (table));
+
+  if (rows)
+    *rows = table->nrows;
+
+  if (columns)
+    *columns = table->ncols;
+}
+
 static void
 gtk_table_finalize (GObject *object)
 {
@@ -862,6 +889,7 @@ gtk_table_remove (GtkContainer *container,
 {
   GtkTable *table = GTK_TABLE (container);
   GtkTableChild *child;
+  GtkWidget *widget_container = GTK_WIDGET (container);
   GList *children;
 
   children = table->children;
@@ -873,15 +901,15 @@ gtk_table_remove (GtkContainer *container,
       
       if (child->widget == widget)
 	{
-	  gboolean was_visible = GTK_WIDGET_VISIBLE (widget);
+	  gboolean was_visible = gtk_widget_get_visible (widget);
 	  
 	  gtk_widget_unparent (widget);
 	  
 	  table->children = g_list_remove (table->children, child);
 	  g_free (child);
 	  
-	  if (was_visible && GTK_WIDGET_VISIBLE (container))
-	    gtk_widget_queue_resize (GTK_WIDGET (container));
+	  if (was_visible && gtk_widget_get_visible (widget_container))
+	    gtk_widget_queue_resize (widget_container);
 	  break;
 	}
     }
@@ -932,7 +960,7 @@ gtk_table_size_request_init (GtkTable *table)
       child = children->data;
       children = children->next;
       
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	gtk_widget_size_request (child->widget, NULL);
 
       if (child->left_attach == (child->right_attach - 1) && child->xexpand)
@@ -957,7 +985,7 @@ gtk_table_size_request_pass1 (GtkTable *table)
       child = children->data;
       children = children->next;
       
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  GtkRequisition child_requisition;
 	  gtk_widget_get_child_requisition (child->widget, &child_requisition);
@@ -1020,7 +1048,7 @@ gtk_table_size_request_pass3 (GtkTable *table)
       child = children->data;
       children = children->next;
       
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  /* Child spans multiple columns.
 	   */
@@ -1173,7 +1201,7 @@ gtk_table_size_allocate_init (GtkTable *table)
       child = children->data;
       children = children->next;
       
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  if (child->left_attach == (child->right_attach - 1))
 	    {
@@ -1208,7 +1236,7 @@ gtk_table_size_allocate_init (GtkTable *table)
       child = children->data;
       children = children->next;
       
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  if (child->left_attach != (child->right_attach - 1))
 	    {
@@ -1545,7 +1573,7 @@ gtk_table_size_allocate_pass2 (GtkTable *table)
       child = children->data;
       children = children->next;
       
-      if (GTK_WIDGET_VISIBLE (child->widget))
+      if (gtk_widget_get_visible (child->widget))
 	{
 	  GtkRequisition child_requisition;
 	  gtk_widget_get_child_requisition (child->widget, &child_requisition);
@@ -1611,6 +1639,3 @@ gtk_table_size_allocate_pass2 (GtkTable *table)
 	}
     }
 }
-
-#define __GTK_TABLE_C__
-#include "gtkaliasdef.c"
