@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -73,16 +73,16 @@ GtkToolItem *gtk_tool_button_new_from_stock (const gchar *stock_id);
 
 void                  gtk_tool_button_set_label         (GtkToolButton *button,
 							 const gchar   *label);
-const gchar *         gtk_tool_button_get_label         (GtkToolButton *button);
+G_CONST_RETURN gchar *gtk_tool_button_get_label         (GtkToolButton *button);
 void                  gtk_tool_button_set_use_underline (GtkToolButton *button,
 							 gboolean       use_underline);
 gboolean              gtk_tool_button_get_use_underline (GtkToolButton *button);
 void                  gtk_tool_button_set_stock_id      (GtkToolButton *button,
 							 const gchar   *stock_id);
-const gchar *         gtk_tool_button_get_stock_id      (GtkToolButton *button);
+G_CONST_RETURN gchar *gtk_tool_button_get_stock_id      (GtkToolButton *button);
 void                  gtk_tool_button_set_icon_name     (GtkToolButton *button,
 							 const gchar   *icon_name);
-const gchar *         gtk_tool_button_get_icon_name     (GtkToolButton *button);
+G_CONST_RETURN gchar *gtk_tool_button_get_icon_name     (GtkToolButton *button);
 void                  gtk_tool_button_set_icon_widget   (GtkToolButton *button,
 							 GtkWidget     *icon_widget);
 GtkWidget *           gtk_tool_button_get_icon_widget   (GtkToolButton *button);
