@@ -24,8 +24,6 @@
 
 #include <string.h>
 
-#undef GTK_DISABLE_DEPRECATED /* GtkTooltips */
-
 #include "gtktoolitem.h"
 #include "gtkmarshalers.h"
 #include "gtktoolshell.h"
@@ -34,11 +32,28 @@
 #include "gtkintl.h"
 #include "gtkmain.h"
 #include "gtkprivate.h"
-#include "gtkalias.h"
+
 
 /**
  * SECTION:gtktoolitem
  * @short_description: The base class of widgets that can be added to GtkToolShell
+ * @Title: GtkToolItem
+ * @see_also: <variablelist>
+ *   <varlistentry>
+ *     <term>#GtkToolbar</term>
+ *     <listitem><para>The toolbar widget</para></listitem>
+ *   </varlistentry>
+ *   <varlistentry>
+ *     <term>#GtkToolButton</term>
+ *     <listitem><para>A subclass of #GtkToolItem that displays buttons on
+ *         the toolbar</para></listitem>
+ *   </varlistentry>
+ *   <varlistentry>
+ *     <term>#GtkSeparatorToolItem</term>
+ *     <listitem><para>A subclass of #GtkToolItem that separates groups of
+ *         items on a toolbar</para></listitem>
+ *   </varlistentry>
+ * </variablelist>
  *
  * #GtkToolItem<!-- -->s are widgets that can appear on a toolbar. To
  * create a toolbar item that contain something else than a button, use
@@ -62,7 +77,6 @@
 enum {
   CREATE_MENU_PROXY,
   TOOLBAR_RECONFIGURED,
-  SET_TOOLTIP,
   LAST_SIGNAL
 };
 
@@ -122,18 +136,12 @@ static void gtk_tool_item_size_request  (GtkWidget      *widget,
 					 GtkRequisition *requisition);
 static void gtk_tool_item_size_allocate (GtkWidget      *widget,
 					 GtkAllocation  *allocation);
-static gboolean gtk_tool_item_real_set_tooltip (GtkToolItem *tool_item,
-						GtkTooltips *tooltips,
-						const gchar *tip_text,
-						const gchar *tip_private);
-
-static gboolean gtk_tool_item_create_menu_proxy (GtkToolItem *item);
 
 static void gtk_tool_item_activatable_interface_init (GtkActivatableIface  *iface);
-static void gtk_tool_item_activatable_update         (GtkActivatable       *activatable,
+static void gtk_tool_item_update                     (GtkActivatable       *activatable,
 						      GtkAction            *action,
 						      const gchar          *property_name);
-static void gtk_tool_item_activatable_reset          (GtkActivatable       *activatable,
+static void gtk_tool_item_sync_action_properties     (GtkActivatable       *activatable,
 						      GtkAction            *action);
 static void gtk_tool_item_set_related_action         (GtkToolItem          *item, 
 						      GtkAction            *action);
@@ -169,8 +177,7 @@ gtk_tool_item_class_init (GtkToolItemClass *klass)
   widget_class->size_allocate = gtk_tool_item_size_allocate;
   widget_class->parent_set    = gtk_tool_item_parent_set;
 
-  klass->create_menu_proxy = gtk_tool_item_create_menu_proxy;
-  klass->set_tooltip       = gtk_tool_item_real_set_tooltip;
+  klass->create_menu_proxy = _gtk_tool_item_create_menu_proxy;
   
   g_object_class_install_property (object_class,
 				   PROP_VISIBLE_HORIZONTAL,
@@ -260,33 +267,6 @@ gtk_tool_item_class_init (GtkToolItemClass *klass)
 		  NULL, NULL,
 		  _gtk_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
-/**
- * GtkToolItem::set-tooltip:
- * @tool_item: the object the signal was emitted on
- * @tooltips: the #GtkTooltips
- * @tip_text: the tooltip text
- * @tip_private: the tooltip private text
- *
- * This signal is emitted when the toolitem's tooltip changes.
- * Application developers can use gtk_tool_item_set_tooltip() to
- * set the item's tooltip.
- *
- * Return value: %TRUE if the signal was handled, %FALSE if not
- *
- * Deprecated: 2.12: With the new tooltip API, there is no
- *   need to use this signal anymore.
- **/
-  toolitem_signals[SET_TOOLTIP] =
-    g_signal_new (I_("set-tooltip"),
-		  G_OBJECT_CLASS_TYPE (klass),
-		  G_SIGNAL_RUN_LAST,
-		  G_STRUCT_OFFSET (GtkToolItemClass, set_tooltip),
-		  _gtk_boolean_handled_accumulator, NULL,
-		  _gtk_marshal_BOOLEAN__OBJECT_STRING_STRING,
-		  G_TYPE_BOOLEAN, 3,
-		  GTK_TYPE_TOOLTIPS,
-		  G_TYPE_STRING,
-		  G_TYPE_STRING);		  
 
   g_type_class_add_private (object_class, sizeof (GtkToolItemPrivate));
 }
@@ -294,7 +274,7 @@ gtk_tool_item_class_init (GtkToolItemClass *klass)
 static void
 gtk_tool_item_init (GtkToolItem *toolitem)
 {
-  GTK_WIDGET_UNSET_FLAGS (toolitem, GTK_CAN_FOCUS);  
+  gtk_widget_set_can_focus (GTK_WIDGET (toolitem), FALSE);
 
   toolitem->priv = GTK_TOOL_ITEM_GET_PRIVATE (toolitem);
 
@@ -411,7 +391,7 @@ gtk_tool_item_property_notify (GObject    *object,
 
   if (tool_item->priv->menu_item && strcmp (pspec->name, "sensitive") == 0)
     gtk_widget_set_sensitive (tool_item->priv->menu_item,
-			      GTK_WIDGET_SENSITIVE (tool_item));
+			      gtk_widget_get_sensitive (GTK_WIDGET (tool_item)));
 }
 
 static void
@@ -448,7 +428,7 @@ gtk_tool_item_realize (GtkWidget *widget)
   GtkToolItem *toolitem;
 
   toolitem = GTK_TOOL_ITEM (widget);
-  GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
+  gtk_widget_set_realized (widget, TRUE);
 
   widget->window = gtk_widget_get_parent_window (widget);
   g_object_ref (widget->window);
@@ -510,7 +490,7 @@ gtk_tool_item_size_request (GtkWidget      *widget,
 {
   GtkWidget *child = GTK_BIN (widget)->child;
 
-  if (child && GTK_WIDGET_VISIBLE (child))
+  if (child && gtk_widget_get_visible (child))
     {
       gtk_widget_size_request (child, requisition);
     }
@@ -543,7 +523,7 @@ gtk_tool_item_size_allocate (GtkWidget     *widget,
                             widget->allocation.width - border_width * 2,
                             widget->allocation.height - border_width * 2);
   
-  if (child && GTK_WIDGET_VISIBLE (child))
+  if (child && gtk_widget_get_visible (child))
     {
       child_allocation.x = allocation->x + border_width;
       child_allocation.y = allocation->y + border_width;
@@ -554,8 +534,8 @@ gtk_tool_item_size_allocate (GtkWidget     *widget,
     }
 }
 
-static gboolean
-gtk_tool_item_create_menu_proxy (GtkToolItem *item)
+gboolean
+_gtk_tool_item_create_menu_proxy (GtkToolItem *item)
 {
   GtkWidget *menu_item;
   gboolean visible_overflown;
@@ -574,22 +554,24 @@ gtk_tool_item_create_menu_proxy (GtkToolItem *item)
 	}
       else
 	gtk_tool_item_set_proxy_menu_item (item, "gtk-action-menu-item", NULL);
+
+      return TRUE;
     }
 
   return FALSE;
 }
 
-static void 
-gtk_tool_item_activatable_interface_init (GtkActivatableIface  *iface)
+static void
+gtk_tool_item_activatable_interface_init (GtkActivatableIface *iface)
 {
-  iface->update = gtk_tool_item_activatable_update;
-  iface->reset = gtk_tool_item_activatable_reset;
+  iface->update = gtk_tool_item_update;
+  iface->sync_action_properties = gtk_tool_item_sync_action_properties;
 }
 
-static void 
-gtk_tool_item_activatable_update (GtkActivatable       *activatable,
-				  GtkAction            *action,
-				  const gchar          *property_name)
+static void
+gtk_tool_item_update (GtkActivatable *activatable,
+		      GtkAction      *action,
+	     	      const gchar    *property_name)
 {
   if (strcmp (property_name, "visible") == 0)
     {
@@ -614,9 +596,9 @@ gtk_tool_item_activatable_update (GtkActivatable       *activatable,
 				    gtk_action_get_is_important (action));
 }
 
-static void 
-gtk_tool_item_activatable_reset (GtkActivatable       *activatable,
-				 GtkAction            *action)
+static void
+gtk_tool_item_sync_action_properties (GtkActivatable *activatable,
+				      GtkAction      *action)
 {
   if (!action)
     return;
@@ -656,14 +638,14 @@ gtk_tool_item_set_related_action (GtkToolItem *item,
 }
 
 static void
-gtk_tool_item_set_use_action_appearance (GtkToolItem *item, 
+gtk_tool_item_set_use_action_appearance (GtkToolItem *item,
 					 gboolean     use_appearance)
 {
   if (item->priv->use_action_appearance != use_appearance)
     {
       item->priv->use_action_appearance = use_appearance;
-      
-      gtk_activatable_reset (GTK_ACTIVATABLE (item), item->priv->action);
+
+      gtk_activatable_sync_action_properties (GTK_ACTIVATABLE (item), item->priv->action);
     }
 }
 
@@ -687,6 +669,33 @@ gtk_tool_item_new (void)
   return item;
 }
 
+/**
+ * gtk_tool_item_get_ellipsize_mode:
+ * @tool_item: a #GtkToolItem
+ *
+ * Returns the ellipsize mode used for @tool_item. Custom subclasses of
+ * #GtkToolItem should call this function to find out how text should
+ * be ellipsized.
+ *
+ * Return value: a #PangoEllipsizeMode indicating how text in @tool_item
+ * should be ellipsized.
+ *
+ * Since: 2.20
+ **/
+PangoEllipsizeMode
+gtk_tool_item_get_ellipsize_mode (GtkToolItem *tool_item)
+{
+  GtkWidget *parent;
+  
+  g_return_val_if_fail (GTK_IS_TOOL_ITEM (tool_item), GTK_ORIENTATION_HORIZONTAL);
+
+  parent = GTK_WIDGET (tool_item)->parent;
+  if (!parent || !GTK_IS_TOOL_SHELL (parent))
+    return PANGO_ELLIPSIZE_NONE;
+
+  return gtk_tool_shell_get_ellipsize_mode (GTK_TOOL_SHELL (parent));
+}
+
 /**
  * gtk_tool_item_get_icon_size:
  * @tool_item: a #GtkToolItem
@@ -695,7 +704,8 @@ gtk_tool_item_new (void)
  * #GtkToolItem should call this function to find out what size icons
  * they should use.
  * 
- * Return value: a #GtkIconSize indicating the icon size used for @tool_item
+ * Return value: (type int): a #GtkIconSize indicating the icon size
+ * used for @tool_item
  * 
  * Since: 2.4
  **/
@@ -812,17 +822,96 @@ gtk_tool_item_get_relief_style (GtkToolItem *tool_item)
 }
 
 /**
- * gtk_tool_item_set_expand:
- * @tool_item: a #GtkToolItem 
- * @expand: Whether @tool_item is allocated extra space
+ * gtk_tool_item_get_text_alignment:
+ * @tool_item: a #GtkToolItem: 
  * 
+ * Returns the text alignment used for @tool_item. Custom subclasses of
+ * #GtkToolItem should call this function to find out how text should
+ * be aligned.
+ * 
+ * Return value: a #gfloat indicating the horizontal text alignment
+ * used for @tool_item
+ * 
+ * Since: 2.20
+ **/
+gfloat
+gtk_tool_item_get_text_alignment (GtkToolItem *tool_item)
+{
+  GtkWidget *parent;
+  
+  g_return_val_if_fail (GTK_IS_TOOL_ITEM (tool_item), GTK_ORIENTATION_HORIZONTAL);
+
+  parent = GTK_WIDGET (tool_item)->parent;
+  if (!parent || !GTK_IS_TOOL_SHELL (parent))
+    return 0.5;
+
+  return gtk_tool_shell_get_text_alignment (GTK_TOOL_SHELL (parent));
+}
+
+/**
+ * gtk_tool_item_get_text_orientation:
+ * @tool_item: a #GtkToolItem
+ *
+ * Returns the text orientation used for @tool_item. Custom subclasses of
+ * #GtkToolItem should call this function to find out how text should
+ * be orientated.
+ *
+ * Return value: a #GtkOrientation indicating the text orientation
+ * used for @tool_item
+ *
+ * Since: 2.20
+ */
+GtkOrientation
+gtk_tool_item_get_text_orientation (GtkToolItem *tool_item)
+{
+  GtkWidget *parent;
+  
+  g_return_val_if_fail (GTK_IS_TOOL_ITEM (tool_item), GTK_ORIENTATION_HORIZONTAL);
+
+  parent = GTK_WIDGET (tool_item)->parent;
+  if (!parent || !GTK_IS_TOOL_SHELL (parent))
+    return GTK_ORIENTATION_HORIZONTAL;
+
+  return gtk_tool_shell_get_text_orientation (GTK_TOOL_SHELL (parent));
+}
+
+/**
+ * gtk_tool_item_get_text_size_group:
+ * @tool_item: a #GtkToolItem
+ *
+ * Returns the size group used for labels in @tool_item. Custom subclasses of
+ * #GtkToolItem should call this function and use the size group for labels.
+ *
+ * Return value: a #GtkSizeGroup
+ *
+ * Since: 2.20
+ */
+GtkSizeGroup *
+gtk_tool_item_get_text_size_group (GtkToolItem *tool_item)
+{
+  GtkWidget *parent;
+  
+  g_return_val_if_fail (GTK_IS_TOOL_ITEM (tool_item), NULL);
+
+  parent = GTK_WIDGET (tool_item)->parent;
+  if (!parent || !GTK_IS_TOOL_SHELL (parent))
+    return NULL;
+
+  return gtk_tool_shell_get_text_size_group (GTK_TOOL_SHELL (parent));
+}
+
+/**
+ * gtk_tool_item_set_expand:
+ * @tool_item: a #GtkToolItem
+ * @expand: Whether @tool_item is allocated extra space
+ *
  * Sets whether @tool_item is allocated extra space when there
  * is more room on the toolbar then needed for the items. The
  * effect is that the item gets bigger when the toolbar gets bigger
  * and smaller when the toolbar gets smaller.
- * 
+ *
  * Since: 2.4
- **/
+ */
 void
 gtk_tool_item_set_expand (GtkToolItem *tool_item,
 			  gboolean     expand)
@@ -954,51 +1043,6 @@ gtk_tool_item_set_is_important (GtkToolItem *tool_item, gboolean is_important)
     }
 }
 
-static gboolean
-gtk_tool_item_real_set_tooltip (GtkToolItem *tool_item,
-				GtkTooltips *tooltips,
-				const gchar *tip_text,
-				const gchar *tip_private)
-{
-  GtkWidget *child = GTK_BIN (tool_item)->child;
-
-  if (!child)
-    return FALSE;
-
-  gtk_widget_set_tooltip_text (child, tip_text);
-
-  return TRUE;
-}
-
-/**
- * gtk_tool_item_set_tooltip:
- * @tool_item: a #GtkToolItem 
- * @tooltips: The #GtkTooltips object to be used
- * @tip_text: text to be used as tooltip text for @tool_item
- * @tip_private: text to be used as private tooltip text
- *
- * Sets the #GtkTooltips object to be used for @tool_item, the
- * text to be displayed as tooltip on the item and the private text
- * to be used. See gtk_tooltips_set_tip().
- * 
- * Since: 2.4
- *
- * Deprecated: 2.12: Use gtk_tool_item_set_tooltip_text() instead.
- **/
-void
-gtk_tool_item_set_tooltip (GtkToolItem *tool_item,
-			   GtkTooltips *tooltips,
-			   const gchar *tip_text,
-			   const gchar *tip_private)
-{
-  gboolean retval;
-  
-  g_return_if_fail (GTK_IS_TOOL_ITEM (tool_item));
-
-  g_signal_emit (tool_item, toolitem_signals[SET_TOOLTIP], 0,
-		 tooltips, tip_text, tip_private, &retval);
-}
-
 /**
  * gtk_tool_item_set_tooltip_text:
  * @tool_item: a #GtkToolItem 
@@ -1073,10 +1117,11 @@ gtk_tool_item_set_use_drag_window (GtkToolItem *toolitem,
       
       if (use_drag_window)
 	{
-	  if (!toolitem->priv->drag_window && GTK_WIDGET_REALIZED (toolitem))
+	  if (!toolitem->priv->drag_window &&
+              gtk_widget_get_realized (GTK_WIDGET (toolitem)))
 	    {
 	      create_drag_window(toolitem);
-	      if (GTK_WIDGET_MAPPED (toolitem))
+	      if (gtk_widget_get_mapped (GTK_WIDGET (toolitem)))
 		gdk_window_show (toolitem->priv->drag_window);
 	    }
 	}
@@ -1210,10 +1255,10 @@ gtk_tool_item_get_visible_vertical (GtkToolItem *toolitem)
  * Returns the #GtkMenuItem that was last set by
  * gtk_tool_item_set_proxy_menu_item(), ie. the #GtkMenuItem
  * that is going to appear in the overflow menu.
- * 
- * Return value: The #GtkMenuItem that is going to appear in the
+ *
+ * Return value: (transfer none): The #GtkMenuItem that is going to appear in the
  * overflow menu for @tool_item.
- * 
+ *
  * Since: 2.4
  **/
 GtkWidget *
@@ -1261,20 +1306,19 @@ gtk_tool_item_get_proxy_menu_item (GtkToolItem *tool_item,
 }
 
 /**
- * gtk_tool_item_rebuild_menu()
+ * gtk_tool_item_rebuild_menu:
  * @tool_item: a #GtkToolItem
- * 
+ *
  * Calling this function signals to the toolbar that the
  * overflow menu item for @tool_item has changed. If the
  * overflow menu is visible when this function it called,
  * the menu will be rebuilt.
  *
- * The function must be called when the tool item
- * changes what it will do in response to the "create_menu_proxy"
- * signal.
- * 
+ * The function must be called when the tool item changes what it
+ * will do in response to the #GtkToolItem::create-menu-proxy signal.
+ *
  * Since: 2.6
- **/
+ */
 void
 gtk_tool_item_rebuild_menu (GtkToolItem *tool_item)
 {
@@ -1323,7 +1367,7 @@ gtk_tool_item_set_proxy_menu_item (GtkToolItem *tool_item,
 	  g_object_ref_sink (menu_item);
 
 	  gtk_widget_set_sensitive (menu_item,
-				    GTK_WIDGET_SENSITIVE (tool_item));
+				    gtk_widget_get_sensitive (GTK_WIDGET (tool_item)));
 	}
       
       tool_item->priv->menu_item = menu_item;
@@ -1359,6 +1403,3 @@ gtk_tool_item_toolbar_reconfigured (GtkToolItem *tool_item)
 
   gtk_widget_queue_resize (GTK_WIDGET (tool_item));
 }
-
-#define __GTK_TOOL_ITEM_C__
-#include "gtkaliasdef.c"
