@@ -76,6 +76,14 @@ match_theme_image (GtkStyle       *style,
 	  match_data->gap_side != image->match_data.gap_side)
 	continue;
 
+      if ((flags & THEME_MATCH_EXPANDER_STYLE) &&
+	  match_data->expander_style != image->match_data.expander_style)
+	continue;
+
+      if ((flags & THEME_MATCH_WINDOW_EDGE) &&
+	  match_data->window_edge != image->match_data.window_edge)
+	continue;
+
       if (image->match_data.detail &&
 	  (!match_data->detail ||
 	   strcmp (match_data->detail, image->match_data.detail) != 0))
@@ -101,14 +109,9 @@ draw_simple_image(GtkStyle       *style,
 		  gint            height)
 {
   ThemeImage *image;
-  gboolean setbg = FALSE;
   
   if ((width == -1) && (height == -1))
-    {
-      gdk_drawable_get_size(window, &width, &height);
-      if (allow_setbg)
-      	setbg = TRUE;
-    }
+    gdk_drawable_get_size(window, &width, &height);
   else if (width == -1)
     gdk_drawable_get_size(window, &width, NULL);
   else if (height == -1)
@@ -164,13 +167,9 @@ draw_gap_image(GtkStyle       *style,
 	       gint            gap_width)
 {
   ThemeImage *image;
-  gboolean setbg = FALSE;
   
   if ((width == -1) && (height == -1))
-    {
-      gdk_drawable_get_size(window, &width, &height);
-      setbg = TRUE;
-    }
+    gdk_drawable_get_size(window, &width, &height);
   else if (width == -1)
     gdk_drawable_get_size(window, &width, NULL);
   else if (height == -1)
@@ -445,7 +444,7 @@ reverse_engineer_stepper_box (GtkWidget    *range,
   gint box_width;
   gint box_height;
   
-  if (range)
+  if (range && GTK_IS_RANGE (range))
     {
       gtk_widget_style_get (range,
 			    "slider_width", &slider_width,
@@ -587,44 +586,6 @@ draw_diamond (GtkStyle     *style,
 				x, y, width, height);
 }
 
-static void
-draw_string (GtkStyle * style,
-	     GdkWindow * window,
-	     GtkStateType state,
-	     GdkRectangle * area,
-	     GtkWidget * widget,
-	     const gchar *detail,
-	     gint x,
-	     gint y,
-	     const gchar * string)
-{
-  g_return_if_fail(style != NULL);
-  g_return_if_fail(window != NULL);
-
-  if (state == GTK_STATE_INSENSITIVE)
-    {
-      if (area)
-	{
-	  gdk_gc_set_clip_rectangle(style->white_gc, area);
-	  gdk_gc_set_clip_rectangle(style->fg_gc[state], area);
-	}
-
-      gdk_draw_string(window, gtk_style_get_font (style), style->fg_gc[state], x, y, string);
-      
-      if (area)
-	{
-	  gdk_gc_set_clip_rectangle(style->white_gc, NULL);
-	  gdk_gc_set_clip_rectangle(style->fg_gc[state], NULL);
-	}
-    }
-  else
-    {
-      gdk_gc_set_clip_rectangle(style->fg_gc[state], area);
-      gdk_draw_string(window, gtk_style_get_font (style), style->fg_gc[state], x, y, string);
-      gdk_gc_set_clip_rectangle(style->fg_gc[state], NULL);
-    }
-}
-
 static void
 draw_box (GtkStyle     *style,
 	  GdkWindow    *window,
@@ -865,15 +826,9 @@ draw_extension (GtkStyle       *style,
 {
   ThemeMatchData match_data;
   
-  g_return_if_fail(style != NULL);
-  g_return_if_fail(window != NULL);
+  g_return_if_fail (style != NULL);
+  g_return_if_fail (window != NULL);
 
-  /* Why? */
-  if (width >=0)
-    width++;
-  if (height >=0)
-    height++;
-  
   match_data.function = TOKEN_D_EXTENSION;
   match_data.detail = (gchar *)detail;
   match_data.flags = THEME_MATCH_SHADOW | THEME_MATCH_STATE | THEME_MATCH_GAP_SIDE;
@@ -901,8 +856,8 @@ draw_focus (GtkStyle     *style,
 {
   ThemeMatchData match_data;
   
-  g_return_if_fail(style != NULL);
-  g_return_if_fail(window != NULL);
+  g_return_if_fail (style != NULL);
+  g_return_if_fail (window != NULL);
 
   match_data.function = TOKEN_D_FOCUS;
   match_data.detail = (gchar *)detail;
@@ -983,13 +938,90 @@ draw_handle (GtkStyle      *style,
 			       x, y, width, height, orientation);
 }
 
+static void
+draw_expander (GtkStyle      *style,
+	       GdkWindow     *window,
+	       GtkStateType   state,
+	       GdkRectangle  *area,
+	       GtkWidget     *widget,
+	       const gchar   *detail,
+	       gint           x,
+	       gint           y,
+	       GtkExpanderStyle expander_style)
+{
+#define DEFAULT_EXPANDER_SIZE 12
+
+  ThemeMatchData match_data;
+  gint expander_size;
+  gint radius;
+  
+  g_return_if_fail (style != NULL);
+  g_return_if_fail (window != NULL);
+
+  if (widget &&
+      gtk_widget_class_find_style_property (GTK_WIDGET_GET_CLASS (widget),
+                                            "expander-size"))
+    {
+      gtk_widget_style_get (widget,
+			    "expander-size", &expander_size,
+			    NULL);
+    }
+  else
+    expander_size = DEFAULT_EXPANDER_SIZE;
+
+  radius = expander_size/2;
+
+  match_data.function = TOKEN_D_EXPANDER;
+  match_data.detail = (gchar *)detail;
+  match_data.flags = (THEME_MATCH_STATE | 
+		      THEME_MATCH_EXPANDER_STYLE);
+  match_data.state = state;
+  match_data.expander_style = expander_style;
+
+  if (!draw_simple_image (style, window, area, widget, &match_data, TRUE, TRUE,
+			  x - radius, y - radius, expander_size, expander_size))
+    parent_class->draw_expander (style, window, state, area, widget, detail,
+				 x, y, expander_style);
+}
+
+static void
+draw_resize_grip (GtkStyle      *style,
+		     GdkWindow     *window,
+		     GtkStateType   state,
+		     GdkRectangle  *area,
+		     GtkWidget     *widget,
+		     const gchar   *detail,
+		     GdkWindowEdge  edge,
+		     gint           x,
+		     gint           y,
+		     gint           width,
+		     gint           height)
+{
+  ThemeMatchData match_data;
+  
+  g_return_if_fail (style != NULL);
+  g_return_if_fail (window != NULL);
+
+  match_data.function = TOKEN_D_RESIZE_GRIP;
+  match_data.detail = (gchar *)detail;
+  match_data.flags = (THEME_MATCH_STATE | 
+		      THEME_MATCH_WINDOW_EDGE);
+  match_data.state = state;
+  match_data.window_edge = edge;
+
+  if (!draw_simple_image (style, window, area, widget, &match_data, TRUE, TRUE,
+			  x, y, width, height))
+    parent_class->draw_resize_grip (style, window, state, area, widget, detail,
+				    edge, x, y, width, height);
+}
+
 GType pixbuf_type_style = 0;
 
-void
-pixbuf_style_register_type (GTypeModule *module)
+void 
+pixbuf_style_register_type (GTypeModule *module) 
 {
-  static const GTypeInfo object_info =
-  {
+  const GTypeInfo object_info =
+    {
     sizeof (PixbufStyleClass),
     (GBaseInitFunc) NULL,
     (GBaseFinalizeFunc) NULL,
@@ -1024,7 +1056,6 @@ pixbuf_style_class_init (PixbufStyleClass *klass)
   style_class->draw_shadow = draw_shadow;
   style_class->draw_arrow = draw_arrow;
   style_class->draw_diamond = draw_diamond;
-  style_class->draw_string = draw_string;
   style_class->draw_box = draw_box;
   style_class->draw_flat_box = draw_flat_box;
   style_class->draw_check = draw_check;
@@ -1036,4 +1067,6 @@ pixbuf_style_class_init (PixbufStyleClass *klass)
   style_class->draw_focus = draw_focus;
   style_class->draw_slider = draw_slider;
   style_class->draw_handle = draw_handle;
+  style_class->draw_expander = draw_expander;
+  style_class->draw_resize_grip = draw_resize_grip;
 }
